      subroutine ddmrate1(ny,nr,r,gain,loss)
      implicit none
c
c----CAMx v6.20 yymmdd
c
c     DDMRATE1 computes species production and loss rates
c     needed only for DDM rate constant sensitivity
c
c     Copyright 1996 - 2015
c     ENVIRON International Corporation
c     Created by the CMC version 5.2.4
c
c --- Subroutines Called:
c        none
c
c --- Called by:
c        EBISOLV
c
c --- Argument definitions:
c        ny   - dimension of gain and loss
c        nr   - dimension of r
c        r    - reaction rates (hr-1)
c        gain - species production (ppm/hr)
c        loss - species destruction (ppm/hr)
c
c --- Includes:
      include "camx.prm"
      include "chmdat.inc"
      include "ddmchm.inc"
c
c --- Arguments:
      integer ny, nr
      real    loss(ny+1), gain(ny+1)
      real    r(nr)
c
c --- Entry Point:
c
c
c-----Calculate the species rates
c
c
c    NO   NO2    O3     O   O1D    OH   HO2  HONO   PNA   PAN
c  C2O3   NO3  N2O5
c
        Loss(lNO   )= +( 1.000)*r(  3)+( 1.000)*r(  4)+( 2.000)*r( 24)
     &                +( 1.000)*r( 25)+( 1.000)*r( 29)+( 1.000)*r( 40)
     &                +( 1.000)*r( 41)+( 1.000)*r( 53)+( 1.000)*r( 61)
     &                +( 1.000)*r( 68)+( 1.000)*r( 71)+( 1.000)*r( 75)
     &                +( 1.000)*r( 79)+( 1.000)*r( 83)+( 1.000)*r(103)
     &                +( 1.000)*r(151)+( 1.000)*r(167)+( 1.000)*r(176)
     &                +( 1.000)*r(181)+( 1.000)*r(186)+( 1.000)*r(207)
     &                +( 1.000)*r(223)+( 1.000)*r(228)
c
        Gain(lNO   )= +( 1.000)*r(  1)+( 1.000)*r(  5)+( 1.000)*r( 28)
     &                +( 1.000)*r( 30)+( 1.000)*r( 42)+( 1.000)*r( 43)
     &                +( 1.000)*r( 68)
c
        Loss(lNO2  )= +( 1.000)*r(  1)+( 1.000)*r(  5)+( 1.000)*r(  6)
     &                +( 1.000)*r( 26)+( 1.000)*r( 30)+( 1.000)*r( 36)
     &                +( 1.000)*r( 41)+( 1.000)*r( 45)+( 1.000)*r( 48)
     &                +( 1.000)*r( 54)+( 1.000)*r( 62)+( 1.000)*r(135)
     &                +( 1.000)*r(192)+( 1.000)*r(208)+( 1.000)*r(224)
c
        Gain(lNO2  )= +( 1.000)*r(  3)+( 1.000)*r(  4)+( 2.000)*r( 24)
     &                +( 1.000)*r( 25)+( 1.000)*r( 27)+( 2.000)*r( 29)
     &                +( 1.000)*r( 30)+( 1.000)*r( 31)+( 1.000)*r( 32)
     &                +( 1.000)*r( 33)+( 1.000)*r( 34)+( 2.000)*r( 35)
     &                +( 1.000)*r( 37)+( 1.000)*r( 38)+( 1.000)*r( 42)
     &                +( 1.000)*r( 44)+( 1.000)*r( 47)+( 1.000)*r( 49)
     &                +( 0.590)*r( 50)+( 1.000)*r( 51)+( 1.000)*r( 53)
     &                +( 1.000)*r( 55)+( 0.600)*r( 56)+( 1.000)*r( 61)
     &                +( 1.000)*r( 63)+( 0.600)*r( 64)+( 1.000)*r( 71)
        Gain(lNO2  ) = Gain(lNO2  )
     &                +( 1.000)*r( 75)+( 1.000)*r( 79)+( 1.000)*r( 92)
     &                +( 1.000)*r(103)+( 0.500)*r(140)+( 0.500)*r(144)
     &                +( 0.500)*r(148)+( 0.900)*r(151)+( 0.350)*r(157)
     &                +( 0.142)*r(160)+( 1.000)*r(167)+( 0.444)*r(170)
     &                +( 0.470)*r(174)+( 0.918)*r(176)+( 0.860)*r(181)
     &                +( 0.860)*r(186)+( 0.500)*r(200)+( 1.000)*r(207)
     &                +( 1.000)*r(209)+( 0.500)*r(213)+( 1.000)*r(214)
     &                +( 1.000)*r(223)+( 1.000)*r(228)
c
        Loss(lO3   )= +( 1.000)*r(  3)+( 1.000)*r(  7)+( 1.000)*r(  8)
     &                +( 1.000)*r(  9)+( 1.000)*r( 12)+( 1.000)*r( 13)
     &                +( 1.000)*r( 26)+( 1.000)*r( 34)+( 1.000)*r(139)
     &                +( 1.000)*r(143)+( 1.000)*r(147)+( 1.000)*r(156)
     &                +( 1.000)*r(159)+( 1.000)*r(173)+( 1.000)*r(199)
     &                +( 1.000)*r(203)+( 1.000)*r(219)+( 1.000)*r(230)
c
        Gain(lO3   )= +( 1.000)*r(  2)+( 0.150)*r( 57)+( 0.150)*r( 65)
     &                +( 0.150)*r(210)
c
        Loss(lO    )= +( 1.000)*r(  2)+( 1.000)*r(  4)+( 1.000)*r(  5)
     &                +( 1.000)*r(  6)+( 1.000)*r(  7)+( 1.000)*r( 14)
     &                +( 1.000)*r( 15)+( 1.000)*r( 23)+( 1.000)*r( 31)
     &                +( 1.000)*r( 99)+( 1.000)*r(105)+( 1.000)*r(109)
     &                +( 1.000)*r(137)+( 1.000)*r(141)+( 1.000)*r(145)
     &                +( 1.000)*r(150)+( 1.000)*r(171)
c
        Gain(lO    )= +( 1.000)*r(  1)+( 1.000)*r(  8)+( 1.000)*r( 10)
     &                +( 1.000)*r( 16)+( 1.000)*r( 27)+( 1.000)*r(220)
c
        Loss(lO1D  )= +( 1.000)*r( 10)+( 1.000)*r( 11)
c
        Gain(lO1D  )= +( 1.000)*r(  9)
c
        Loss(lOH   )= +( 1.000)*r( 12)+( 1.000)*r( 14)+( 2.000)*r( 16)
     &                +( 2.000)*r( 17)+( 1.000)*r( 18)+( 1.000)*r( 22)
     &                +( 1.000)*r( 32)+( 1.000)*r( 40)+( 1.000)*r( 44)
     &                +( 1.000)*r( 45)+( 1.000)*r( 46)+( 1.000)*r( 51)
     &                +( 1.000)*r( 52)+( 1.000)*r( 87)+( 1.000)*r( 89)
     &                +( 1.000)*r( 91)+( 1.000)*r( 93)+( 1.000)*r( 94)
     &                +( 1.000)*r( 95)+( 1.000)*r( 96)+( 1.000)*r(106)
     &                +( 1.000)*r(110)+( 1.000)*r(113)+( 1.000)*r(116)
     &                +( 1.000)*r(121)+( 1.000)*r(122)+( 1.000)*r(123)
        Loss(lOH   ) = Loss(lOH   )
     &                +( 1.000)*r(124)+( 1.000)*r(125)+( 1.000)*r(126)
     &                +( 1.000)*r(127)+( 1.000)*r(130)+( 1.000)*r(131)
     &                +( 1.000)*r(132)+( 1.000)*r(136)+( 1.000)*r(138)
     &                +( 1.000)*r(142)+( 1.000)*r(146)+( 1.000)*r(149)
     &                +( 1.000)*r(158)+( 1.000)*r(162)+( 1.000)*r(165)
     &                +( 1.000)*r(170)+( 1.000)*r(172)+( 1.000)*r(175)
     &                +( 1.000)*r(180)+( 1.000)*r(185)+( 1.000)*r(190)
     &                +( 1.000)*r(194)+( 1.000)*r(198)+( 1.000)*r(202)
        Loss(lOH   ) = Loss(lOH   )
     &                +( 1.000)*r(205)+( 1.000)*r(213)+( 1.000)*r(214)
     &                +( 1.000)*r(216)+( 1.000)*r(226)
c
        Gain(lOH   )= +( 2.000)*r( 11)+( 1.000)*r( 13)+( 1.000)*r( 15)
     &                +( 2.000)*r( 21)+( 1.000)*r( 23)+( 1.000)*r( 25)
     &                +( 1.000)*r( 33)+( 1.000)*r( 43)+( 1.000)*r( 47)
     &                +( 0.410)*r( 50)+( 0.440)*r( 57)+( 0.440)*r( 65)
     &                +( 0.400)*r( 87)+( 1.000)*r( 88)+( 0.400)*r( 89)
     &                +( 1.000)*r( 90)+( 1.000)*r( 99)+( 0.200)*r(104)
     &                +( 1.000)*r(105)+( 1.000)*r(109)+( 0.190)*r(114)
     &                +( 0.700)*r(136)+( 0.300)*r(137)+( 0.160)*r(139)
     &                +( 0.100)*r(141)+( 0.334)*r(143)+( 0.500)*r(147)
        Gain(lOH   ) = Gain(lOH   )
     &                +( 0.120)*r(152)+( 0.266)*r(156)+( 0.461)*r(159)
     &                +( 0.933)*r(162)+( 1.000)*r(163)+( 1.125)*r(166)
     &                +( 0.125)*r(167)+( 0.100)*r(168)+( 0.125)*r(169)
     &                +( 0.570)*r(173)+( 0.118)*r(175)+( 0.100)*r(180)
     &                +( 0.244)*r(185)+( 0.500)*r(199)+( 0.500)*r(203)
     &                +( 0.440)*r(210)+( 1.000)*r(218)
c
        Loss(lHO2  )= +( 1.000)*r( 13)+( 1.000)*r( 15)+( 1.000)*r( 18)
     &                +( 2.000)*r( 19)+( 2.000)*r( 20)+( 1.000)*r( 25)
     &                +( 1.000)*r( 33)+( 1.000)*r( 48)+( 1.000)*r( 57)
     &                +( 1.000)*r( 65)+( 1.000)*r( 69)+( 1.000)*r( 72)
     &                +( 1.000)*r( 76)+( 1.000)*r( 80)+( 1.000)*r( 84)
     &                +( 1.000)*r(101)+( 1.000)*r(104)+( 1.000)*r(152)
     &                +( 1.000)*r(166)+( 1.000)*r(178)+( 1.000)*r(183)
     &                +( 1.000)*r(187)+( 1.000)*r(193)+( 1.000)*r(210)
     &                +( 1.000)*r(222)
c
        Gain(lHO2  )= +( 1.000)*r( 12)+( 1.000)*r( 14)+( 1.000)*r( 22)
     &                +( 1.000)*r( 23)+( 1.000)*r( 32)+( 1.000)*r( 49)
     &                +( 0.590)*r( 50)+( 1.000)*r( 52)+( 1.000)*r( 69)
     &                +( 1.000)*r( 71)+( 0.900)*r( 73)+( 0.370)*r( 74)
     &                +( 1.000)*r( 75)+( 0.800)*r( 77)+( 0.600)*r( 78)
     &                +( 0.800)*r( 85)+( 1.000)*r( 90)+( 1.000)*r( 93)
     &                +( 1.000)*r( 96)+( 2.000)*r( 97)+( 1.000)*r( 99)
     &                +( 1.000)*r(100)+( 1.000)*r(102)+( 1.000)*r(103)
     &                +( 0.200)*r(104)+( 1.000)*r(108)+( 1.000)*r(112)
        Gain(lHO2  ) = Gain(lHO2  )
     &                +( 0.200)*r(113)+( 1.400)*r(114)+( 1.000)*r(116)
     &                +( 2.000)*r(117)+( 1.000)*r(118)+( 1.000)*r(119)
     &                +( 1.000)*r(122)+( 1.000)*r(123)+( 1.000)*r(126)
     &                +( 0.900)*r(127)+( 1.000)*r(134)+( 0.300)*r(136)
     &                +( 1.000)*r(137)+( 0.160)*r(139)+( 0.100)*r(141)
     &                +( 0.080)*r(143)+( 0.250)*r(150)+( 0.818)*r(151)
     &                +( 0.120)*r(152)+( 0.728)*r(153)+( 0.728)*r(154)
     &                +( 1.000)*r(155)+( 0.066)*r(156)+( 0.137)*r(158)
        Gain(lHO2  ) = Gain(lHO2  )
     &                +( 0.398)*r(159)+( 0.760)*r(161)+( 0.825)*r(166)
     &                +( 0.825)*r(167)+( 0.660)*r(168)+( 0.825)*r(169)
     &                +( 0.530)*r(175)+( 0.918)*r(176)+( 1.000)*r(177)
     &                +( 1.000)*r(179)+( 0.180)*r(180)+( 0.860)*r(181)
     &                +( 1.000)*r(182)+( 1.000)*r(184)+( 0.155)*r(185)
     &                +( 0.860)*r(186)+( 1.000)*r(188)+( 1.000)*r(189)
     &                +( 1.000)*r(190)+( 1.000)*r(196)+( 0.700)*r(197)
     &                +( 1.000)*r(201)+( 0.560)*r(203)+( 0.200)*r(205)
        Gain(lHO2  ) = Gain(lHO2  )
     &                +( 0.800)*r(207)
c
        Loss(lHONO )= +( 2.000)*r( 42)+( 1.000)*r( 43)+( 1.000)*r( 44)
c
        Gain(lHONO )= +( 1.000)*r( 40)+( 2.000)*r( 41)+( 1.000)*r(196)
c
        Loss(lPNA  )= +( 1.000)*r( 49)+( 1.000)*r( 50)+( 1.000)*r( 51)
c
        Gain(lPNA  )= +( 1.000)*r( 48)
c
        Loss(lPAN  )= +( 1.000)*r( 55)+( 1.000)*r( 56)
c
        Gain(lPAN  )= +( 1.000)*r( 54)
c
        Loss(lC2O3 )= +( 1.000)*r( 53)+( 1.000)*r( 54)+( 1.000)*r( 57)
     &                +( 1.000)*r( 58)+( 2.000)*r( 59)+( 1.000)*r( 60)
     &                +( 1.000)*r( 73)+( 1.000)*r( 77)+( 1.000)*r( 81)
     &                +( 1.000)*r( 85)+( 1.000)*r(153)+( 1.000)*r(168)
     &                +( 1.000)*r(177)+( 1.000)*r(182)+( 1.000)*r(188)
     &                +( 1.000)*r(211)
c
        Gain(lC2O3 )= +( 1.000)*r( 55)+( 0.600)*r( 56)+( 1.000)*r( 58)
     &                +( 1.000)*r( 95)+( 1.000)*r(105)+( 1.000)*r(106)
     &                +( 1.000)*r(107)+( 0.800)*r(113)+( 1.000)*r(115)
     &                +( 1.000)*r(119)+( 1.000)*r(120)+( 1.000)*r(121)
     &                +( 0.500)*r(128)+( 0.620)*r(129)+( 1.000)*r(130)
     &                +( 0.269)*r(158)+( 0.143)*r(159)+( 0.208)*r(161)
     &                +( 0.300)*r(197)+( 0.600)*r(199)+( 0.120)*r(203)
c
        Loss(lNO3  )= +( 1.000)*r( 27)+( 1.000)*r( 28)+( 1.000)*r( 29)
     &                +( 1.000)*r( 30)+( 1.000)*r( 31)+( 1.000)*r( 32)
     &                +( 1.000)*r( 33)+( 1.000)*r( 34)+( 2.000)*r( 35)
     &                +( 1.000)*r( 36)+( 1.000)*r(100)+( 1.000)*r(107)
     &                +( 1.000)*r(111)+( 1.000)*r(115)+( 1.000)*r(118)
     &                +( 1.000)*r(120)+( 1.000)*r(140)+( 1.000)*r(144)
     &                +( 1.000)*r(148)+( 1.000)*r(157)+( 1.000)*r(160)
     &                +( 1.000)*r(164)+( 1.000)*r(174)+( 1.000)*r(191)
     &                +( 1.000)*r(195)+( 1.000)*r(200)+( 1.000)*r(204)
        Loss(lNO3  ) = Loss(lNO3  )
     &                +( 1.000)*r(206)
c
        Gain(lNO3  )= +( 1.000)*r(  6)+( 1.000)*r( 26)+( 1.000)*r( 37)
     &                +( 1.000)*r( 38)+( 1.000)*r( 46)+( 0.410)*r( 50)
     &                +( 0.400)*r( 56)+( 0.400)*r( 64)+( 0.185)*r(170)
     &                +( 1.000)*r(231)
c
        Loss(lN2O5 )= +( 1.000)*r( 37)+( 1.000)*r( 38)+( 1.000)*r( 39)
c
        Gain(lN2O5 )= +( 1.000)*r( 36)
c
c
      return
      end

