      subroutine ddmrate6(ny,nr,r,gain,loss)
      implicit none
c
c----CAMx v6.30 160408
c
c     DDMRATE6 computes species production and loss rates
c     needed only for DDM rate constant sensitivity
c
c     Copyright 1996 - 2016
c     Ramboll ENVIRON
c     Created by the CMC version 5.2.4
c
c --- Subroutines Called:
c        none
c
c --- Called by:
c        EBISOLV
c
c --- Argument definitions:
c        ny   - dimension of gain and loss
c        nr   - dimension of r
c        r    - reaction rates (hr-1)
c        gain - species production (ppm/hr)
c        loss - species destruction (ppm/hr)
c
c --- Includes:
      include "camx.prm"
      include "chmdat.inc"
      include "ddmchm.inc"
c
c --- Arguments:
      integer ny, nr
      real    loss(ny+1), gain(ny+1)
      real    r(nr)
c
c --- Entry Point:
c
c
c-----Calculate the species rates
c
c
c    NO   NO2    O3     O   O1D    OH   HO2  HONO   PNA   PAN
c  C2O3   NO3  N2O5
c
        Loss(lNO   )= +( 1.000)*r(  3)+( 1.000)*r(  6)+( 1.000)*r( 16)
     &                +( 2.000)*r( 22)+( 1.000)*r( 23)+( 1.000)*r( 24)
     &                +( 1.000)*r( 30)+( 1.000)*r( 54)+( 1.000)*r( 55)
     &                +( 1.000)*r( 68)+( 1.000)*r( 81)+( 1.000)*r( 88)
     &                +( 1.000)*r(103)+( 1.000)*r(132)
c
        Gain(lNO   )= +( 1.000)*r(  1)+( 1.000)*r(  4)+( 1.000)*r( 15)
     &                +( 1.000)*r( 17)+( 1.000)*r( 25)+( 1.000)*r( 27)
     &                +( 0.200)*r(148)
c
        Loss(lNO2  )= +( 1.000)*r(  1)+( 1.000)*r(  4)+( 1.000)*r(  5)
     &                +( 1.000)*r(  7)+( 1.000)*r( 17)+( 1.000)*r( 18)
     &                +( 1.000)*r( 23)+( 1.000)*r( 28)+( 1.000)*r( 31)
     &                +( 1.000)*r( 89)+( 1.000)*r(104)+( 1.000)*r(118)
     &                +( 1.000)*r(136)+( 1.000)*r(148)
c
        Gain(lNO2  )= +( 1.000)*r(  3)+( 1.000)*r(  6)+( 1.000)*r( 14)
     &                +( 2.000)*r( 16)+( 1.000)*r( 17)+( 1.000)*r( 21)
     &                +( 2.000)*r( 22)+( 1.000)*r( 26)+( 1.000)*r( 27)
     &                +( 1.000)*r( 30)+( 1.000)*r( 32)+( 1.000)*r( 33)
     &                +( 1.000)*r( 46)+( 1.000)*r( 47)+( 1.000)*r( 49)
     &                +( 2.000)*r( 50)+( 0.610)*r( 51)+( 1.000)*r( 52)
     &                +( 1.000)*r( 53)+( 1.000)*r( 54)+( 1.000)*r( 62)
     &                +( 1.000)*r( 68)+( 1.000)*r( 81)+( 1.000)*r( 88)
     &                +( 1.000)*r( 90)+( 1.000)*r( 91)+( 1.000)*r(103)
        Gain(lNO2  ) = Gain(lNO2  )
     &                +( 1.000)*r(105)+( 1.000)*r(106)+( 1.000)*r(107)
     &                +( 1.000)*r(122)+( 1.000)*r(126)+( 1.000)*r(130)
     &                +( 0.900)*r(132)+( 0.200)*r(147)+( 0.470)*r(156)
c
        Loss(lO3   )= +( 1.000)*r(  3)+( 1.000)*r(  7)+( 1.000)*r(  8)
     &                +( 1.000)*r(  9)+( 1.000)*r( 12)+( 1.000)*r( 13)
     &                +( 1.000)*r( 49)+( 1.000)*r(121)+( 1.000)*r(125)
     &                +( 1.000)*r(129)+( 1.000)*r(140)+( 1.000)*r(146)
     &                +( 1.000)*r(150)+( 1.000)*r(155)
c
        Gain(lO3   )= +( 1.000)*r(  2)+( 0.200)*r( 92)+( 0.200)*r(108)
c
        Loss(lO    )= +( 1.000)*r(  2)+( 1.000)*r(  4)+( 1.000)*r(  5)
     &                +( 1.000)*r(  6)+( 1.000)*r( 40)+( 1.000)*r( 44)
     &                +( 1.000)*r( 45)+( 1.000)*r( 46)+( 1.000)*r( 77)
     &                +( 1.000)*r( 84)+( 1.000)*r( 99)+( 1.000)*r(119)
     &                +( 1.000)*r(123)+( 1.000)*r(127)+( 1.000)*r(144)
     &                +( 1.000)*r(153)
c
        Gain(lO    )= +( 1.000)*r(  1)+( 1.000)*r(  8)+( 1.000)*r( 10)
     &                +( 1.000)*r( 14)+( 1.000)*r( 41)+( 0.500)*r(129)
c
        Loss(lO1D  )= +( 1.000)*r( 10)+( 1.000)*r( 11)+( 1.000)*r( 38)
c
        Gain(lO1D  )= +( 1.000)*r(  9)
c
        Loss(lOH   )= +( 1.000)*r( 12)+( 1.000)*r( 24)+( 1.000)*r( 26)
     &                +( 1.000)*r( 28)+( 1.000)*r( 29)+( 1.000)*r( 33)
     &                +( 1.000)*r( 37)+( 1.000)*r( 39)+( 1.000)*r( 40)
     &                +( 2.000)*r( 41)+( 2.000)*r( 42)+( 1.000)*r( 43)
     &                +( 1.000)*r( 47)+( 1.000)*r( 61)+( 1.000)*r( 63)
     &                +( 1.000)*r( 64)+( 1.000)*r( 66)+( 1.000)*r( 67)
     &                +( 1.000)*r( 71)+( 1.000)*r( 73)+( 1.000)*r( 74)
     &                +( 1.000)*r( 83)+( 1.000)*r( 85)+( 1.000)*r( 96)
     &                +( 1.000)*r( 98)+( 1.000)*r(100)+( 1.000)*r(107)
        Loss(lOH   ) = Loss(lOH   )
     &                +( 1.000)*r(113)+( 1.000)*r(114)+( 1.000)*r(115)
     &                +( 1.000)*r(120)+( 1.000)*r(124)+( 1.000)*r(128)
     &                +( 1.000)*r(131)+( 1.000)*r(134)+( 1.000)*r(139)
     &                +( 1.000)*r(141)+( 1.000)*r(142)+( 1.000)*r(145)
     &                +( 1.000)*r(149)+( 1.000)*r(154)
c
        Gain(lOH   )= +( 2.000)*r( 11)+( 1.000)*r( 13)+( 1.000)*r( 25)
     &                +( 1.000)*r( 30)+( 2.000)*r( 36)+( 1.000)*r( 38)
     &                +( 1.000)*r( 44)+( 1.000)*r( 45)+( 0.390)*r( 51)
     &                +( 1.000)*r( 52)+( 1.000)*r( 65)+( 1.000)*r( 72)
     &                +( 1.000)*r( 77)+( 1.000)*r( 84)+( 1.000)*r( 97)
     &                +( 1.000)*r( 99)+( 0.100)*r(119)+( 0.100)*r(121)
     &                +( 0.300)*r(123)+( 0.130)*r(125)+( 0.500)*r(129)
     &                +( 0.080)*r(140)+( 0.266)*r(146)+( 0.268)*r(150)
     &                +( 0.570)*r(155)
c
        Loss(lHO2  )= +( 1.000)*r( 13)+( 1.000)*r( 30)+( 1.000)*r( 31)
     &                +( 2.000)*r( 34)+( 2.000)*r( 35)+( 1.000)*r( 43)
     &                +( 1.000)*r( 44)+( 1.000)*r( 48)+( 1.000)*r( 56)
     &                +( 1.000)*r( 57)+( 1.000)*r( 69)+( 1.000)*r( 79)
     &                +( 1.000)*r( 82)+( 1.000)*r( 92)+( 1.000)*r(108)
     &                +( 1.000)*r(137)
c
        Gain(lHO2  )= +( 1.000)*r( 12)+( 1.000)*r( 32)+( 1.000)*r( 37)
     &                +( 1.000)*r( 38)+( 1.000)*r( 39)+( 1.000)*r( 40)
     &                +( 1.000)*r( 45)+( 1.000)*r( 47)+( 0.610)*r( 51)
     &                +( 1.000)*r( 61)+( 1.000)*r( 62)+( 1.000)*r( 63)
     &                +( 1.000)*r( 65)+( 1.000)*r( 66)+( 1.000)*r( 68)
     &                +( 0.740)*r( 70)+( 0.300)*r( 71)+( 1.000)*r( 72)
     &                +( 1.000)*r( 73)+( 1.000)*r( 74)+( 2.000)*r( 75)
     &                +( 1.000)*r( 77)+( 1.000)*r( 78)+( 1.000)*r( 80)
     &                +( 1.000)*r( 81)+( 1.000)*r( 83)+( 1.000)*r( 87)
        Gain(lHO2  ) = Gain(lHO2  )
     &                +( 0.900)*r( 93)+( 1.000)*r(102)+( 1.000)*r(103)
     &                +( 1.000)*r(109)+( 2.000)*r(111)+( 1.000)*r(112)
     &                +( 1.000)*r(113)+( 1.000)*r(114)+( 0.110)*r(115)
     &                +( 0.940)*r(116)+( 1.000)*r(117)+( 0.300)*r(119)
     &                +( 0.950)*r(120)+( 0.440)*r(121)+( 1.700)*r(123)
     &                +( 1.000)*r(124)+( 0.130)*r(125)+( 0.100)*r(127)
     &                +( 1.000)*r(128)+( 0.500)*r(129)+( 1.000)*r(130)
     &                +( 0.440)*r(131)+( 0.900)*r(132)+( 1.000)*r(133)
        Gain(lHO2  ) = Gain(lHO2  )
     &                +( 0.600)*r(134)+( 1.000)*r(138)+( 2.000)*r(139)
     &                +( 0.760)*r(140)+( 0.700)*r(141)+( 1.000)*r(143)
     &                +( 0.250)*r(144)+( 0.912)*r(145)+( 0.066)*r(146)
     &                +( 0.800)*r(147)+( 0.800)*r(148)+( 0.503)*r(149)
     &                +( 0.154)*r(150)+( 0.925)*r(151)+( 1.033)*r(152)
     &                +( 0.750)*r(154)+( 0.070)*r(155)+( 0.280)*r(156)
c
        Loss(lHONO )= +( 1.000)*r( 25)+( 1.000)*r( 26)+( 2.000)*r( 27)
c
        Gain(lHONO )= +( 2.000)*r( 23)+( 1.000)*r( 24)
c
        Loss(lPNA  )= +( 1.000)*r( 32)+( 1.000)*r( 33)+( 1.000)*r( 51)
c
        Gain(lPNA  )= +( 1.000)*r( 31)
c
        Loss(lPAN  )= +( 1.000)*r( 90)+( 1.000)*r( 91)
c
        Gain(lPAN  )= +( 1.000)*r( 89)
c
        Loss(lC2O3 )= +( 1.000)*r( 88)+( 1.000)*r( 89)+( 1.000)*r( 92)
     &                +( 1.000)*r( 93)+( 1.000)*r( 94)+( 2.000)*r( 95)
     &                +( 1.000)*r(112)
c
        Gain(lC2O3 )= +( 1.000)*r( 84)+( 1.000)*r( 85)+( 1.000)*r( 86)
     &                +( 1.000)*r( 90)+( 1.000)*r( 91)+( 1.000)*r( 96)
     &                +( 1.000)*r(138)+( 1.000)*r(139)+( 0.620)*r(140)
     &                +( 1.000)*r(142)+( 1.000)*r(143)+( 0.210)*r(149)
     &                +( 0.114)*r(150)+( 0.967)*r(152)
c
        Loss(lNO3  )= +( 1.000)*r( 14)+( 1.000)*r( 15)+( 1.000)*r( 16)
     &                +( 1.000)*r( 17)+( 1.000)*r( 18)+( 1.000)*r( 46)
     &                +( 1.000)*r( 47)+( 1.000)*r( 48)+( 1.000)*r( 49)
     &                +( 2.000)*r( 50)+( 1.000)*r( 78)+( 1.000)*r( 86)
     &                +( 1.000)*r(101)+( 1.000)*r(122)+( 1.000)*r(126)
     &                +( 1.000)*r(130)+( 1.000)*r(135)+( 1.000)*r(147)
     &                +( 1.000)*r(151)+( 1.000)*r(156)
c
        Gain(lNO3  )= +( 1.000)*r(  5)+( 1.000)*r(  7)+( 1.000)*r( 21)
     &                +( 1.000)*r( 29)+( 0.390)*r( 51)+( 1.000)*r( 53)
c
        Loss(lN2O5 )= +( 1.000)*r( 19)+( 1.000)*r( 20)+( 1.000)*r( 21)
     &                +( 1.000)*r( 53)
c
        Gain(lN2O5 )= +( 1.000)*r( 18)
c
c
      return
      end

