      subroutine hr_iox1(y0,y1,yh,H2O,M,O2,CH4,H2,ny,rk,r,nr,dt)
      implicit none
c
c----CAMx v6.10 yymmdd
c
c     HR_IOX1 solves I, IO and OIO for 3 EBI iterations
c
c     Copyright 1996 - 2013
c     ENVIRON International Corporation
c     Created by the CMC version 5.2   ***PROTOTYPE CREATED BY HAND***
c
c --- Subroutines Called:
c        none
c
c --- Called by:
c        EBISOLV
c
c --- Argument definitions:
c        y0  - initial Conc for this step (ppm)
c        yh  - current Conc iteration (ppm)
c        y1  - next Conc iteration (ppm)
c        H2O - water vapor Conc (ppm)
c        M   - total gas Conc (ppm)
c        O2  - oxygen Conc (ppm)
c        CH4 - methane Conc (ppm)
c        H2  - hydrogen Conc (ppm)
c        ny  - dimension of y0, y1 and yh
c        rk  - rate constants (ppm-n hr-1)
c        r   - reaction rates (hr-1)
c        nr  - dimension of rk and r
c        dt  - time step (hr)
c
c --- Includes:
      include "camx.prm"
      include "chmdat.inc"
      include "ddmchm.inc"
c
c --- Arguments:
      integer ny, nr
      real y0(ny+1), y1(ny+1), yh(ny+1)
      real rk(nr), r(nr)
      real H2O, M, O2, CH4, H2, dt
c
c --- Local variables:
      real N2
      real r217, r218, r219, r220, r221, r222, r223, r224
      real r225, r226, r227, r228, r229, r230, r231, r232
      real gainI, gainIO, gainOIO, lossI, lossIO, lossOIO
c
c --- Entry Point
c
      N2 = M - O2
c
c     1st iteration
c
      r217 = r(217)
      r218 = r(218)
      r219 = r(219)
      r220 = r(220)
      r221 = r(221)
      r222 = r(222)
      r223 = r(223)
      r224 = r(224)
      r225 = r(225)
      r226 = r(226)
      r227 = r(227)
      r228 = r(228)
      r229 = r(229)
      r230 = r(230)
      r231 = r(231)
      r232 = r(232)
c
        lossI    = +( 1.000)*r219
        gainI    = +( 2.000)*r217+( 1.000)*r218+( 1.000)*r220
     &             +( 0.400)*r221+( 1.000)*r223+( 1.000)*r225
     &             +( 1.000)*r229+( 1.000)*r231
        lossIO   = +( 1.000)*r220+( 2.000)*r221+( 1.000)*r222
     &             +( 1.000)*r223+( 1.000)*r224+( 1.000)*r227
        gainIO   = +( 1.000)*r219+( 1.000)*r228
        lossOIO  = +( 1.000)*r225+( 1.000)*r226+( 1.000)*r227
     &             +( 1.000)*r228
        gainOIO  = +( 0.400)*r221+( 1.000)*r229
c
        y1(lI) = (y0(lI) + gainI*dt)
     &                              / (1.0 + lossI*dt/yh(lI))
        y1(lIO) = (y0(lIO) + gainIO*dt)
     &                              / (1.0 + lossIO*dt/yh(lIO))
        y1(lOIO) = (y0(lOIO) + gainOIO*dt)
     &                              / (1.0 + lossOIO*dt/yh(lOIO))
        y1(lI) = MIN(1.0, MAX(1.0E-20,y1(lI)))
        y1(lIO) = MIN(1.0, MAX(1.0E-20,y1(lIO)))
        y1(lOIO) = MIN(1.0, MAX(1.0E-20,y1(lOIO)))
c
c     2nd iteration
c
      r219 = rk(219)*y1(lI)*yh(lO3)
      r220 = rk(220)*y1(lIO)
      r221 = rk(221)*y1(lIO)*y1(lIO)
      r222 = rk(222)*y1(lIO)*yh(lHO2)
      r223 = rk(223)*y1(lIO)*yh(lNO)
      r224 = rk(224)*y1(lIO)*yh(lNO2)
      r225 = rk(225)*y1(lOIO)
      r226 = rk(226)*y1(lOIO)*yh(lOH)
      r227 = rk(227)*y1(lOIO)*y1(lIO)
      r228 = rk(228)*y1(lOIO)*yh(lNO)
c
        lossI    = +( 1.000)*r219
        gainI    = +( 2.000)*r217+( 1.000)*r218+( 1.000)*r220
     &             +( 0.400)*r221+( 1.000)*r223+( 1.000)*r225
     &             +( 1.000)*r229+( 1.000)*r231
        lossIO   = +( 1.000)*r220+( 2.000)*r221+( 1.000)*r222
     &             +( 1.000)*r223+( 1.000)*r224+( 1.000)*r227
        gainIO   = +( 1.000)*r219+( 1.000)*r228
        lossOIO  = +( 1.000)*r225+( 1.000)*r226+( 1.000)*r227
     &             +( 1.000)*r228
        gainOIO  = +( 0.400)*r221+( 1.000)*r229
c
        y1(lI) = (y0(lI) + gainI*dt)
     &                              / (1.0 + lossI*dt/y1(lI))
        y1(lIO) = (y0(lIO) + gainIO*dt)
     &                              / (1.0 + lossIO*dt/y1(lIO))
        y1(lOIO) = (y0(lOIO) + gainOIO*dt)
     &                              / (1.0 + lossOIO*dt/y1(lOIO))
        y1(lI) = MIN(1.0, MAX(1.0E-20,y1(lI)))
        y1(lIO) = MIN(1.0, MAX(1.0E-20,y1(lIO)))
        y1(lOIO) = MIN(1.0, MAX(1.0E-20,y1(lOIO)))
c
c     3rd iteration
c
      r219 = rk(219)*y1(lI)*yh(lO3)
      r220 = rk(220)*y1(lIO)
      r221 = rk(221)*y1(lIO)*y1(lIO)
      r222 = rk(222)*y1(lIO)*yh(lHO2)
      r223 = rk(223)*y1(lIO)*yh(lNO)
      r224 = rk(224)*y1(lIO)*yh(lNO2)
      r225 = rk(225)*y1(lOIO)
      r226 = rk(226)*y1(lOIO)*yh(lOH)
      r227 = rk(227)*y1(lOIO)*y1(lIO)
      r228 = rk(228)*y1(lOIO)*yh(lNO)
c
        lossI    = +( 1.000)*r219
        gainI    = +( 2.000)*r217+( 1.000)*r218+( 1.000)*r220
     &             +( 0.400)*r221+( 1.000)*r223+( 1.000)*r225
     &             +( 1.000)*r229+( 1.000)*r231
        lossIO   = +( 1.000)*r220+( 2.000)*r221+( 1.000)*r222
     &             +( 1.000)*r223+( 1.000)*r224+( 1.000)*r227
        gainIO   = +( 1.000)*r219+( 1.000)*r228
        lossOIO  = +( 1.000)*r225+( 1.000)*r226+( 1.000)*r227
     &             +( 1.000)*r228
        gainOIO  = +( 0.400)*r221+( 1.000)*r229
c
        y1(lI) = (y0(lI) + gainI*dt)
     &                              / (1.0 + lossI*dt/y1(lI))
        y1(lIO) = (y0(lIO) + gainIO*dt)
     &                              / (1.0 + lossIO*dt/y1(lIO))
        y1(lOIO) = (y0(lOIO) + gainOIO*dt)
     &                              / (1.0 + lossOIO*dt/y1(lOIO))
        y1(lI) = MIN(1.0, MAX(1.0E-20,y1(lI)))
        y1(lIO) = MIN(1.0, MAX(1.0E-20,y1(lIO)))
        y1(lOIO) = MIN(1.0, MAX(1.0E-20,y1(lOIO)))
c
c
      return
      end
