c----CAMx v6.30 160408
c  
c     CHMDAT.INC contains all chemistry variables 
c                            
c     Copyright 1996 - 2016
c     Ramboll ENVIRON
c            
c     Modifications:  
c       4/4/00     Added aerosol deposition variables to /aerochm/
c       1/9/02     Aerosol size cut points and density now a function of
c                  species
c       8/20/02    Added minimum CWC to define presence of clouds
c      12/12/02    Expanded species list for Mechanism 4
c       1/10/03    Added array for deposition output species names
c      10/14/04    Modifications for mechanism 10
c      11/30/06    Created by taking Static variables out of chmstry.com
c      12/29/06 -bkoo-     Expanded species list for the updated SOA scheme
c      01/08/07 -bkoo-     Expanded species list for Mechanism 6 (CB05)
c                          Now ipigrxn is a scalar pointer to NO self-reaction
c      07/04/07 -bkoo-     Added pointer to hydrolysis of N2O5
c      04/28/08 -gyarwood- Added EBI solver
c      04/12/12 -cemery-   Added T and P adjustments to photolysis rates
c      07/20/12 -ou-       Added Mechanism 1 (CB06 with Iodine chemistry)
c      10/08/12 -jjung-    Added Mechanism 2 (CB6r1)
c      04/30/13 -cemery-   Added surface model
c      06/28/13 -bkoo-     Added indexes for new GREASD PiG chemistry
c      10/14/13 -bkoo-     Added pointer to hydrolysis of organic nitrate
c      10/24/13 -bkoo-     Revised Mechanism 2 (CB6r1 -> CB6r2)
c      03/18/14 -bkoo-     Added species for benzene SOA
c      04/07/14 -cemery-   Added top con file
c      06/27/14 -bkoo-     Added Mechanism 3 (CB6r2h)
c      11/11/14 -bkoo-     Added Mechanism 4 (CB6r3)
c      12/07/14 -bkoo-     Added species for VBS
c      01/08/16 -bkoo-     Updated for SAPRC99->SAPRC07TC
c                                      Revised VBS
c                                      Removal of IEH solver
c      02/29/16 -bkoo-     Added pointer to heterogeneous rxn of N2O5 + HCL
c 
c-----------------------------------------------------------------------
c     Parameters for some of the switches:
c
c     CDCMC  -- string for requesting the CMC chemistry solver
c     CDEBI  -- string for requesting the EBI chemistry solver
c     CDIEH  -- string for requesting the IEH chemistry solver
c     CDLSOD -- string for requesting the LSODE chemistry solver
c     IDCMC  -- code for using the CMC chemistry solver
c     IDEBI  -- code for using the EBI chemistry solver
c     IDIEH  -- code for using the IEH chemistry solver
c     IDLSOD -- code for using the LSODE chemistry solver
c
c-----------------------------------------------------------------------
c
      character*10 CDCMC
      character*10 CDEBI
      character*10 CDIEH
      character*10 CDLSOD
      integer      IDCMC
      integer      IDEBI
      integer      IDIEH
      integer      IDLSOD
c
      parameter( CDCMC  = "CMC       " )
      parameter( CDEBI  = "EBI       " )
      parameter( CDIEH  = "IEH       " )
      parameter( CDLSOD = "LSODE     " )
      parameter( IDCMC  = 1 )
      parameter( IDEBI  = 2 )
      parameter( IDIEH  = 3 )
      parameter( IDLSOD = 4 )
c 
c-----------------------------------------------------------------------
c    Variables for the number of species in input files:
c
c    ngas   --  number of gas species being modeled
c    naero  --  number of aersol species being modeled
c    nspec  --  total number of modeled species
c    nrad   --  number of radical species being modeled
c    nreact --  number of chemical reactions
c    idmech --  the code which determines which chemical mechanism is used
c    idsolv --  the code which determines which chemstry solver to use
c    navspc --  number of species to write to output average file
c    ndepspc--  number of species to write to deposition file
c    nicspc --  number of species in the initial conditions file
c    nbcspc --  number of species in the boundary conditions file
c    ntcspc --  number of species in the top concentrations file
c    nptspc --  number of species in the point source emissions file
c    nsmspc --  number of species in surface model
c    nsmrxn --  number of reactions in surface model
c
c-----------------------------------------------------------------------
c
       integer   ngas
       integer   naero
       integer   nspec
       integer   nrad
       integer   nreact
       integer   idmech
       integer   idsolv
       integer   navspc
       integer   ndepspc
       integer   nicspc
       integer   nbcspc
       integer   ntcspc
       integer   nptspc
       integer   nsmspc
       integer   nsmrxn
c
      common /chm1/ ngas, naero, nspec, nrad, nreact,
     &                         idmech, idsolv, navspc, ndepspc, nicspc,
     &                           nbcspc, ntcspc, nptspc, nsmspc, nsmrxn
c
c-----------------------------------------------------------------------
c
c    aeropt --  keyword for aerosol scheme ('NONE', 'INERT', 'CF' or 'CMU')
c
c-----------------------------------------------------------------------
c
      character*10 aeropt
c
      common /chm2/ aeropt
c
c-----------------------------------------------------------------------
c     Variables for photolysis data:
c
c     nphot1   -- number of primary photolysis reactions
c     nphot2   -- number of secondary (scaled) photolysis reactions
c
c-----------------------------------------------------------------------
c
      integer nphot1
      integer nphot2
c
      common /photmap/ nphot1, nphot2
c 
c-----------------------------------------------------------------------
c     Mercury chemistry variables 
c     Variables for vertical profiles of Cl2, Br and BrO for Hg chemistry
c
c     NHTHAL   --  number of heights for halogen concentrations 
c     hthal    --  heights (km) for the top of each concentration range
c     cl2day  --  profile of Cl2 (ppm) with height during day over ocean
c     cl2nite --  profile of Cl2 (ppm) with height at night over ocean
c     brlprof  --  profile of Br (ppm) with height over land
c     brwprof  --  profile of Br (ppm) with height over ocean
c     brolprof --  profile of BrO (ppm) with height over land
c     browprof --  profile of BrO (ppm) with height over ocean
c
c     MWHG     --  Hg molecular weight 
c-----------------------------------------------------------------------
c
      integer, parameter :: NHTHAL = 6
      real, parameter :: MWHG = 200.59
c
      real, dimension(NHTHAL) :: hthal,brlprof,brwprof,brolprof,
     &                           browprof,cl2day,cl2nite
c
      common /halprofs/ hthal, brlprof, brwprof, brolprof, browprof,
     &                  cl2day, cl2nite
c 
c-----------------------------------------------------------------------
c     Parameters for mapping input species to internal model order:
c
c      NSPNAM  -- number of recognizable state species
c
      integer   NSPNAM
c
      parameter ( NSPNAM  =   491 )
c 
c-----------------------------------------------------------------------
c     Variables for mapping input species to internal model order:
c
c     kmap     -- mapping of species on chemistry parameters file to
c                 internal order
c
c-----------------------------------------------------------------------
c
      integer kmap(NSPNAM)
c
      common /kname/ kmap
c
      integer      kaacd,   kacet,   kacro
      integer      kacye,   kafg1,   kafg2
      integer      kafg3,   kald2,   kaldx
      integer      kalk1,   kalk2,   kalk3
      integer      kalk4,   kalk5,   kapin
      integer      karo1,   karo2,   kb124
      integer      kbacl,   kbald,   kbd13
      integer      kbenz,   kbnza,   kbnzb
      integer        kbr,    kbr2,   kbrn2
      integer      kbrn3,    kbro,   kbzc3
      integer       kbzo,   kbzo2,   kc2o3
      integer      kcat1,   kccho,    kcg1
      integer       kcg2,    kcg3,    kcg4
      integer       kcg5,    kcg6,    kcg7
      integer      kch3i,     kcl,    kcl2
      integer      kcln2,   kcln3,    kclo
      integer        kco,   kco3h,   kcooh
      integer      kcres,    kcro,   kcron
      integer      kcxo3,   kech4,   kepox
      integer      kepx2,    keth,   ketha
      integer      kethe,   kethy,   ketoh
      integer      kfacd,   kfmbr,   kfmcl
      integer      kform,    kgly,   kglyd
      integer      kh2o2,    khbr,   khcho
      integer       khcl,   khco3,    khg0
      integer       khg2,     khi,   khio3
      integer      khno3,    kho2,   khobr
      integer      khocl,    khoi,   khono
      integer      khpld,      ki,     ki2
      integer      ki2o2,   kialk,   kino2
      integer      kino3,   kintr,     kio
      integer      kiole,   kiprd,   kiso2
      integer      kisop,    kisp,   kispa
      integer      kispb,   kispd,   kispx
      integer      kivoa,   kivob,   kivod
      integer      kivog,   kixoy,    kket
      integer      kmac3,   kmacr,    kmb2
      integer      kmb2c,    kmb3,    kmbc
      integer      kmbc2,   kmco3,    kmek
      integer      kmeo2,   kmeoh,   kmepx
      integer      kmgly,    kmi2,    kmib
      integer       kmic,   kmpan,    kmvk
      integer      kmxyl,   kn2o5,    knh3
      integer        kno,    kno2,    kno3
      integer      knphe,    kntr,   kntr1
      integer      kntr2,      ko,    ko1d
      integer        ko3,    ko3p,     koh
      integer       koio,    kole,   kole1
      integer      kole2,   kopan,   kopen
      integer      kopo3,   koxyl,   kpacd
      integer       kpan,   kpan2,   kpanx
      integer       kpar,   kpbzn,    kpna
      integer      kprd2,   kprpa,   kprpe
      integer      kpxyl,   kr6px,   krapx
      integer      krcho,   krco3,   krno3
      integer       kro2,   kro2c,   kro2x
      integer      kro3h,   krooh,    kror
      integer      ksesq,    kso2,    ksqt
      integer      kssbr,   ksscl,   kssn3
      integer      ksulf,   ktbuo,   kterp
      integer       kto2,    ktol,   ktola
      integer      ktolb,   ktolu,    ktrp
      integer      ktrpa,   ktrpb,   kvap1
      integer      kvap2,   kvap3,   kvap4
      integer      kvas1,   kvas2,   kvas3
      integer      kvas4,   kvbs1,   kvbs2
      integer      kvbs3,   kvbs4,   kvcp1
      integer      kvcp2,   kvcp3,   kvcp4
      integer      kvfp1,   kvfp2,   kvfp3
      integer      kvfp4,   kxace,   kxacr
      integer      kxaf1,   kxaf2,   kxaf3
      integer      kxbac,   kxbal,   kxcch
      integer       kxco,   kxgld,   kxgly
      integer      kxhch,   kxho2,   kxipr
      integer      kxlo2,   kxma3,   kxmac
      integer      kxmc3,   kxmek,   kxmeo
      integer      kxmgl,   kxmvk,     kxn
      integer      kxno2,    kxo2,   kxo2h
      integer      kxo2n,    kxoh,   kxopn
      integer      kxpar,   kxpd2,   kxprp
      integer      kxrc3,   kxrch,   kxrn3
      integer      kxtbu,    kxyl,   kxyla
      integer      kxylb,   ky6px,   kyapx
      integer      kyrpx,   kzrn3,   kpso4
      integer      kpno3,   kpnh4,    kpoa
      integer      ksoa1,   ksoa2,   ksoa3
      integer      ksoa4,   ksoa5,   ksoa6
      integer      ksoa7,   ksoah,   ksopa
      integer      ksopb,    kpec,   kfcrs
      integer      kfprm,   kccrs,   kcprm
      integer        kna,    kpcl,   kph2o
      integer     khgiip, khgiipc,    khgp
      integer      kpap0,   kpap1,   kpap2
      integer      kpap3,   kpap4,   kpas0
      integer      kpas1,   kpas2,   kpas3
      integer      kpas4,   kpbs0,   kpbs1
      integer      kpbs2,   kpbs3,   kpbs4
      integer      kpcp0,   kpcp1,   kpcp2
      integer      kpcp3,   kpcp4,   kpfp0
      integer      kpfp1,   kpfp2,   kpfp3
      integer      kpfp4, kpso4_1, kpso4_2
      integer    kpso4_3, kpso4_4, kpso4_5
      integer    kpso4_6, kpso4_7, kpso4_8
      integer    kpso4_9,kpso4_10, kpno3_1
      integer    kpno3_2, kpno3_3, kpno3_4
      integer    kpno3_5, kpno3_6, kpno3_7
      integer    kpno3_8, kpno3_9,kpno3_10
      integer    kpnh4_1, kpnh4_2, kpnh4_3
      integer    kpnh4_4, kpnh4_5, kpnh4_6
      integer    kpnh4_7, kpnh4_8, kpnh4_9
      integer   kpnh4_10,  kpoa_1,  kpoa_2
      integer     kpoa_3,  kpoa_4,  kpoa_5
      integer     kpoa_6,  kpoa_7,  kpoa_8
      integer     kpoa_9, kpoa_10, ksoa1_1
      integer    ksoa1_2, ksoa1_3, ksoa1_4
      integer    ksoa1_5, ksoa1_6, ksoa1_7
      integer    ksoa1_8, ksoa1_9,ksoa1_10
      integer    ksoa2_1, ksoa2_2, ksoa2_3
      integer    ksoa2_4, ksoa2_5, ksoa2_6
      integer    ksoa2_7, ksoa2_8, ksoa2_9
      integer   ksoa2_10, ksoa3_1, ksoa3_2
      integer    ksoa3_3, ksoa3_4, ksoa3_5
      integer    ksoa3_6, ksoa3_7, ksoa3_8
      integer    ksoa3_9,ksoa3_10, ksoa4_1
      integer    ksoa4_2, ksoa4_3, ksoa4_4
      integer    ksoa4_5, ksoa4_6, ksoa4_7
      integer    ksoa4_8, ksoa4_9,ksoa4_10
      integer    ksoa5_1, ksoa5_2, ksoa5_3
      integer    ksoa5_4, ksoa5_5, ksoa5_6
      integer    ksoa5_7, ksoa5_8, ksoa5_9
      integer   ksoa5_10, ksoa6_1, ksoa6_2
      integer    ksoa6_3, ksoa6_4, ksoa6_5
      integer    ksoa6_6, ksoa6_7, ksoa6_8
      integer    ksoa6_9,ksoa6_10, ksoa7_1
      integer    ksoa7_2, ksoa7_3, ksoa7_4
      integer    ksoa7_5, ksoa7_6, ksoa7_7
      integer    ksoa7_8, ksoa7_9,ksoa7_10
      integer    ksoah_1, ksoah_2, ksoah_3
      integer    ksoah_4, ksoah_5, ksoah_6
      integer    ksoah_7, ksoah_8, ksoah_9
      integer   ksoah_10, ksopa_1, ksopa_2
      integer    ksopa_3, ksopa_4, ksopa_5
      integer    ksopa_6, ksopa_7, ksopa_8
      integer    ksopa_9,ksopa_10, ksopb_1
      integer    ksopb_2, ksopb_3, ksopb_4
      integer    ksopb_5, ksopb_6, ksopb_7
      integer    ksopb_8, ksopb_9,ksopb_10
      integer     kpec_1,  kpec_2,  kpec_3
      integer     kpec_4,  kpec_5,  kpec_6
      integer     kpec_7,  kpec_8,  kpec_9
      integer    kpec_10, kcrst_1, kcrst_2
      integer    kcrst_3, kcrst_4, kcrst_5
      integer    kcrst_6, kcrst_7, kcrst_8
      integer    kcrst_9,kcrst_10,   kna_1
      integer      kna_2,   kna_3,   kna_4
      integer      kna_5,   kna_6,   kna_7
      integer      kna_8,   kna_9,  kna_10
      integer     kpcl_1,  kpcl_2,  kpcl_3
      integer     kpcl_4,  kpcl_5,  kpcl_6
      integer     kpcl_7,  kpcl_8,  kpcl_9
      integer    kpcl_10, kph2o_1, kph2o_2
      integer    kph2o_3, kph2o_4, kph2o_5
      integer    kph2o_6, kph2o_7, kph2o_8
      integer    kph2o_9,kph2o_10
c
      equivalence
     &   (kmap(  1),   kaacd),(kmap(  2),   kacet),(kmap(  3),   kacro),
     &   (kmap(  4),   kacye),(kmap(  5),   kafg1),(kmap(  6),   kafg2),
     &   (kmap(  7),   kafg3),(kmap(  8),   kald2),(kmap(  9),   kaldx),
     &   (kmap( 10),   kalk1),(kmap( 11),   kalk2),(kmap( 12),   kalk3),
     &   (kmap( 13),   kalk4),(kmap( 14),   kalk5),(kmap( 15),   kapin),
     &   (kmap( 16),   karo1),(kmap( 17),   karo2),(kmap( 18),   kb124),
     &   (kmap( 19),   kbacl),(kmap( 20),   kbald),(kmap( 21),   kbd13),
     &   (kmap( 22),   kbenz),(kmap( 23),   kbnza),(kmap( 24),   kbnzb),
     &   (kmap( 25),     kbr),(kmap( 26),    kbr2),(kmap( 27),   kbrn2),
     &   (kmap( 28),   kbrn3),(kmap( 29),    kbro),(kmap( 30),   kbzc3),
     &   (kmap( 31),    kbzo),(kmap( 32),   kbzo2),(kmap( 33),   kc2o3),
     &   (kmap( 34),   kcat1),(kmap( 35),   kccho),(kmap( 36),    kcg1),
     &   (kmap( 37),    kcg2),(kmap( 38),    kcg3),(kmap( 39),    kcg4),
     &   (kmap( 40),    kcg5),(kmap( 41),    kcg6),(kmap( 42),    kcg7),
     &   (kmap( 43),   kch3i),(kmap( 44),     kcl),(kmap( 45),    kcl2),
     &   (kmap( 46),   kcln2),(kmap( 47),   kcln3),(kmap( 48),    kclo),
     &   (kmap( 49),     kco),(kmap( 50),   kco3h),(kmap( 51),   kcooh),
     &   (kmap( 52),   kcres),(kmap( 53),    kcro),(kmap( 54),   kcron),
     &   (kmap( 55),   kcxo3),(kmap( 56),   kech4),(kmap( 57),   kepox),
     &   (kmap( 58),   kepx2),(kmap( 59),    keth),(kmap( 60),   ketha),
     &   (kmap( 61),   kethe),(kmap( 62),   kethy),(kmap( 63),   ketoh),
     &   (kmap( 64),   kfacd),(kmap( 65),   kfmbr),(kmap( 66),   kfmcl),
     &   (kmap( 67),   kform),(kmap( 68),    kgly),(kmap( 69),   kglyd),
     &   (kmap( 70),   kh2o2),(kmap( 71),    khbr),(kmap( 72),   khcho),
     &   (kmap( 73),    khcl),(kmap( 74),   khco3),(kmap( 75),    khg0),
     &   (kmap( 76),    khg2),(kmap( 77),     khi),(kmap( 78),   khio3),
     &   (kmap( 79),   khno3),(kmap( 80),    kho2),(kmap( 81),   khobr),
     &   (kmap( 82),   khocl),(kmap( 83),    khoi),(kmap( 84),   khono),
     &   (kmap( 85),   khpld),(kmap( 86),      ki),(kmap( 87),     ki2),
     &   (kmap( 88),   ki2o2),(kmap( 89),   kialk),(kmap( 90),   kino2),
     &   (kmap( 91),   kino3),(kmap( 92),   kintr),(kmap( 93),     kio),
     &   (kmap( 94),   kiole),(kmap( 95),   kiprd),(kmap( 96),   kiso2),
     &   (kmap( 97),   kisop),(kmap( 98),    kisp),(kmap( 99),   kispa),
     &   (kmap(100),   kispb),(kmap(101),   kispd),(kmap(102),   kispx),
     &   (kmap(103),   kivoa),(kmap(104),   kivob),(kmap(105),   kivod),
     &   (kmap(106),   kivog),(kmap(107),   kixoy),(kmap(108),    kket),
     &   (kmap(109),   kmac3),(kmap(110),   kmacr),(kmap(111),    kmb2),
     &   (kmap(112),   kmb2c),(kmap(113),    kmb3),(kmap(114),    kmbc),
     &   (kmap(115),   kmbc2),(kmap(116),   kmco3),(kmap(117),    kmek),
     &   (kmap(118),   kmeo2),(kmap(119),   kmeoh),(kmap(120),   kmepx),
     &   (kmap(121),   kmgly),(kmap(122),    kmi2),(kmap(123),    kmib),
     &   (kmap(124),    kmic),(kmap(125),   kmpan),(kmap(126),    kmvk),
     &   (kmap(127),   kmxyl),(kmap(128),   kn2o5),(kmap(129),    knh3),
     &   (kmap(130),     kno),(kmap(131),    kno2),(kmap(132),    kno3),
     &   (kmap(133),   knphe),(kmap(134),    kntr),(kmap(135),   kntr1),
     &   (kmap(136),   kntr2),(kmap(137),      ko),(kmap(138),    ko1d),
     &   (kmap(139),     ko3),(kmap(140),    ko3p),(kmap(141),     koh),
     &   (kmap(142),    koio),(kmap(143),    kole),(kmap(144),   kole1),
     &   (kmap(145),   kole2),(kmap(146),   kopan),(kmap(147),   kopen),
     &   (kmap(148),   kopo3),(kmap(149),   koxyl),(kmap(150),   kpacd),
     &   (kmap(151),    kpan),(kmap(152),   kpan2),(kmap(153),   kpanx),
     &   (kmap(154),    kpar),(kmap(155),   kpbzn),(kmap(156),    kpna),
     &   (kmap(157),   kprd2),(kmap(158),   kprpa),(kmap(159),   kprpe),
     &   (kmap(160),   kpxyl),(kmap(161),   kr6px),(kmap(162),   krapx),
     &   (kmap(163),   krcho),(kmap(164),   krco3),(kmap(165),   krno3),
     &   (kmap(166),    kro2),(kmap(167),   kro2c),(kmap(168),   kro2x),
     &   (kmap(169),   kro3h),(kmap(170),   krooh),(kmap(171),    kror),
     &   (kmap(172),   ksesq),(kmap(173),    kso2),(kmap(174),    ksqt),
     &   (kmap(175),   kssbr),(kmap(176),   ksscl),(kmap(177),   kssn3),
     &   (kmap(178),   ksulf),(kmap(179),   ktbuo),(kmap(180),   kterp),
     &   (kmap(181),    kto2),(kmap(182),    ktol),(kmap(183),   ktola),
     &   (kmap(184),   ktolb),(kmap(185),   ktolu),(kmap(186),    ktrp),
     &   (kmap(187),   ktrpa),(kmap(188),   ktrpb),(kmap(189),   kvap1),
     &   (kmap(190),   kvap2),(kmap(191),   kvap3),(kmap(192),   kvap4),
     &   (kmap(193),   kvas1),(kmap(194),   kvas2),(kmap(195),   kvas3),
     &   (kmap(196),   kvas4),(kmap(197),   kvbs1),(kmap(198),   kvbs2),
     &   (kmap(199),   kvbs3),(kmap(200),   kvbs4),(kmap(201),   kvcp1),
     &   (kmap(202),   kvcp2),(kmap(203),   kvcp3),(kmap(204),   kvcp4),
     &   (kmap(205),   kvfp1),(kmap(206),   kvfp2),(kmap(207),   kvfp3),
     &   (kmap(208),   kvfp4),(kmap(209),   kxace),(kmap(210),   kxacr),
     &   (kmap(211),   kxaf1),(kmap(212),   kxaf2),(kmap(213),   kxaf3),
     &   (kmap(214),   kxbac),(kmap(215),   kxbal),(kmap(216),   kxcch),
     &   (kmap(217),    kxco),(kmap(218),   kxgld),(kmap(219),   kxgly),
     &   (kmap(220),   kxhch),(kmap(221),   kxho2),(kmap(222),   kxipr),
     &   (kmap(223),   kxlo2),(kmap(224),   kxma3),(kmap(225),   kxmac),
     &   (kmap(226),   kxmc3),(kmap(227),   kxmek),(kmap(228),   kxmeo),
     &   (kmap(229),   kxmgl),(kmap(230),   kxmvk),(kmap(231),     kxn),
     &   (kmap(232),   kxno2),(kmap(233),    kxo2),(kmap(234),   kxo2h),
     &   (kmap(235),   kxo2n),(kmap(236),    kxoh),(kmap(237),   kxopn),
     &   (kmap(238),   kxpar),(kmap(239),   kxpd2),(kmap(240),   kxprp),
     &   (kmap(241),   kxrc3),(kmap(242),   kxrch),(kmap(243),   kxrn3),
     &   (kmap(244),   kxtbu),(kmap(245),    kxyl),(kmap(246),   kxyla),
     &   (kmap(247),   kxylb),(kmap(248),   ky6px),(kmap(249),   kyapx),
     &   (kmap(250),   kyrpx),(kmap(251),   kzrn3),(kmap(252),   kpso4),
     &   (kmap(253),   kpno3),(kmap(254),   kpnh4),(kmap(255),    kpoa),
     &   (kmap(256),   ksoa1),(kmap(257),   ksoa2),(kmap(258),   ksoa3),
     &   (kmap(259),   ksoa4),(kmap(260),   ksoa5),(kmap(261),   ksoa6),
     &   (kmap(262),   ksoa7),(kmap(263),   ksoah),(kmap(264),   ksopa),
     &   (kmap(265),   ksopb),(kmap(266),    kpec),(kmap(267),   kfcrs),
     &   (kmap(268),   kfprm),(kmap(269),   kccrs),(kmap(270),   kcprm)
      equivalence
     &   (kmap(271),     kna),(kmap(272),    kpcl),(kmap(273),   kph2o),
     &   (kmap(274),  khgiip),(kmap(275), khgiipc),(kmap(276),    khgp),
     &   (kmap(277),   kpap0),(kmap(278),   kpap1),(kmap(279),   kpap2),
     &   (kmap(280),   kpap3),(kmap(281),   kpap4),(kmap(282),   kpas0),
     &   (kmap(283),   kpas1),(kmap(284),   kpas2),(kmap(285),   kpas3),
     &   (kmap(286),   kpas4),(kmap(287),   kpbs0),(kmap(288),   kpbs1),
     &   (kmap(289),   kpbs2),(kmap(290),   kpbs3),(kmap(291),   kpbs4),
     &   (kmap(292),   kpcp0),(kmap(293),   kpcp1),(kmap(294),   kpcp2),
     &   (kmap(295),   kpcp3),(kmap(296),   kpcp4),(kmap(297),   kpfp0),
     &   (kmap(298),   kpfp1),(kmap(299),   kpfp2),(kmap(300),   kpfp3),
     &   (kmap(301),   kpfp4),(kmap(302), kpso4_1),(kmap(303), kpso4_2),
     &   (kmap(304), kpso4_3),(kmap(305), kpso4_4),(kmap(306), kpso4_5),
     &   (kmap(307), kpso4_6),(kmap(308), kpso4_7),(kmap(309), kpso4_8),
     &   (kmap(310), kpso4_9),(kmap(311),kpso4_10),(kmap(312), kpno3_1),
     &   (kmap(313), kpno3_2),(kmap(314), kpno3_3),(kmap(315), kpno3_4),
     &   (kmap(316), kpno3_5),(kmap(317), kpno3_6),(kmap(318), kpno3_7),
     &   (kmap(319), kpno3_8),(kmap(320), kpno3_9),(kmap(321),kpno3_10),
     &   (kmap(322), kpnh4_1),(kmap(323), kpnh4_2),(kmap(324), kpnh4_3),
     &   (kmap(325), kpnh4_4),(kmap(326), kpnh4_5),(kmap(327), kpnh4_6),
     &   (kmap(328), kpnh4_7),(kmap(329), kpnh4_8),(kmap(330), kpnh4_9),
     &   (kmap(331),kpnh4_10),(kmap(332),  kpoa_1),(kmap(333),  kpoa_2),
     &   (kmap(334),  kpoa_3),(kmap(335),  kpoa_4),(kmap(336),  kpoa_5),
     &   (kmap(337),  kpoa_6),(kmap(338),  kpoa_7),(kmap(339),  kpoa_8),
     &   (kmap(340),  kpoa_9),(kmap(341), kpoa_10),(kmap(342), ksoa1_1),
     &   (kmap(343), ksoa1_2),(kmap(344), ksoa1_3),(kmap(345), ksoa1_4),
     &   (kmap(346), ksoa1_5),(kmap(347), ksoa1_6),(kmap(348), ksoa1_7),
     &   (kmap(349), ksoa1_8),(kmap(350), ksoa1_9),(kmap(351),ksoa1_10),
     &   (kmap(352), ksoa2_1),(kmap(353), ksoa2_2),(kmap(354), ksoa2_3),
     &   (kmap(355), ksoa2_4),(kmap(356), ksoa2_5),(kmap(357), ksoa2_6),
     &   (kmap(358), ksoa2_7),(kmap(359), ksoa2_8),(kmap(360), ksoa2_9),
     &   (kmap(361),ksoa2_10),(kmap(362), ksoa3_1),(kmap(363), ksoa3_2),
     &   (kmap(364), ksoa3_3),(kmap(365), ksoa3_4),(kmap(366), ksoa3_5),
     &   (kmap(367), ksoa3_6),(kmap(368), ksoa3_7),(kmap(369), ksoa3_8),
     &   (kmap(370), ksoa3_9),(kmap(371),ksoa3_10),(kmap(372), ksoa4_1),
     &   (kmap(373), ksoa4_2),(kmap(374), ksoa4_3),(kmap(375), ksoa4_4),
     &   (kmap(376), ksoa4_5),(kmap(377), ksoa4_6),(kmap(378), ksoa4_7),
     &   (kmap(379), ksoa4_8),(kmap(380), ksoa4_9),(kmap(381),ksoa4_10),
     &   (kmap(382), ksoa5_1),(kmap(383), ksoa5_2),(kmap(384), ksoa5_3),
     &   (kmap(385), ksoa5_4),(kmap(386), ksoa5_5),(kmap(387), ksoa5_6),
     &   (kmap(388), ksoa5_7),(kmap(389), ksoa5_8),(kmap(390), ksoa5_9),
     &   (kmap(391),ksoa5_10),(kmap(392), ksoa6_1),(kmap(393), ksoa6_2),
     &   (kmap(394), ksoa6_3),(kmap(395), ksoa6_4),(kmap(396), ksoa6_5),
     &   (kmap(397), ksoa6_6),(kmap(398), ksoa6_7),(kmap(399), ksoa6_8),
     &   (kmap(400), ksoa6_9),(kmap(401),ksoa6_10),(kmap(402), ksoa7_1),
     &   (kmap(403), ksoa7_2),(kmap(404), ksoa7_3),(kmap(405), ksoa7_4),
     &   (kmap(406), ksoa7_5),(kmap(407), ksoa7_6),(kmap(408), ksoa7_7),
     &   (kmap(409), ksoa7_8),(kmap(410), ksoa7_9),(kmap(411),ksoa7_10),
     &   (kmap(412), ksoah_1),(kmap(413), ksoah_2),(kmap(414), ksoah_3),
     &   (kmap(415), ksoah_4),(kmap(416), ksoah_5),(kmap(417), ksoah_6),
     &   (kmap(418), ksoah_7),(kmap(419), ksoah_8),(kmap(420), ksoah_9),
     &   (kmap(421),ksoah_10),(kmap(422), ksopa_1),(kmap(423), ksopa_2),
     &   (kmap(424), ksopa_3),(kmap(425), ksopa_4),(kmap(426), ksopa_5),
     &   (kmap(427), ksopa_6),(kmap(428), ksopa_7),(kmap(429), ksopa_8),
     &   (kmap(430), ksopa_9),(kmap(431),ksopa_10),(kmap(432), ksopb_1),
     &   (kmap(433), ksopb_2),(kmap(434), ksopb_3),(kmap(435), ksopb_4),
     &   (kmap(436), ksopb_5),(kmap(437), ksopb_6),(kmap(438), ksopb_7),
     &   (kmap(439), ksopb_8),(kmap(440), ksopb_9),(kmap(441),ksopb_10),
     &   (kmap(442),  kpec_1),(kmap(443),  kpec_2),(kmap(444),  kpec_3),
     &   (kmap(445),  kpec_4),(kmap(446),  kpec_5),(kmap(447),  kpec_6),
     &   (kmap(448),  kpec_7),(kmap(449),  kpec_8),(kmap(450),  kpec_9),
     &   (kmap(451), kpec_10),(kmap(452), kcrst_1),(kmap(453), kcrst_2),
     &   (kmap(454), kcrst_3),(kmap(455), kcrst_4),(kmap(456), kcrst_5),
     &   (kmap(457), kcrst_6),(kmap(458), kcrst_7),(kmap(459), kcrst_8),
     &   (kmap(460), kcrst_9),(kmap(461),kcrst_10),(kmap(462),   kna_1),
     &   (kmap(463),   kna_2),(kmap(464),   kna_3),(kmap(465),   kna_4),
     &   (kmap(466),   kna_5),(kmap(467),   kna_6),(kmap(468),   kna_7),
     &   (kmap(469),   kna_8),(kmap(470),   kna_9),(kmap(471),  kna_10),
     &   (kmap(472),  kpcl_1),(kmap(473),  kpcl_2),(kmap(474),  kpcl_3),
     &   (kmap(475),  kpcl_4),(kmap(476),  kpcl_5),(kmap(477),  kpcl_6),
     &   (kmap(478),  kpcl_7),(kmap(479),  kpcl_8),(kmap(480),  kpcl_9),
     &   (kmap(481), kpcl_10),(kmap(482), kph2o_1),(kmap(483), kph2o_2),
     &   (kmap(484), kph2o_3),(kmap(485), kph2o_4),(kmap(486), kph2o_5),
     &   (kmap(487), kph2o_6),(kmap(488), kph2o_7),(kmap(489), kph2o_8),
     &   (kmap(490), kph2o_9),(kmap(491),kph2o_10)
c
c-----------------------------------------------------------------------
c     Variables to define parameters for each chemical species:
c
c     henso20  -- Henry's Law constant at STP for SO2 (molar/atm)
c     tfactso2 -- Temperature dependence of SO2 Henry's Law constant (1/K)
c     nbin     -- Number of aerosol size bins
c     cwmin    -- Minimum cloud water threshold (g/m3)
c     tamin    -- Cloud water freezing threshold (K)
c
c-----------------------------------------------------------------------
c
      real henso20
      real tfactso2
      real cwmin
      real tamin
c
      common /depchm/ henso20, tfactso2, cwmin, tamin
c
      integer nbin
c
      common /aerochm/ nbin
c
c-----------------------------------------------------------------------
c     Pointers to photolysis reactions that receive T,P adjustments
c
      integer jno2rxn,jo3rxn,jhcho1rxn,jhcho2rxn,jch3chorxn
      common /phtrxn/ jno2rxn,jo3rxn,jhcho1rxn,jhcho2rxn,jch3chorxn
c
c-----------------------------------------------------------------------
c     Pointer to hydrolysis of N2O5
c                    N2O5 + H2O -> 2 HNO3        (ihydrxn)
c                    N2O5 + HCL -> CLN2 + HNO3   (ihydrxn2)
c
      integer ihydrxn, ihydrxn2
      common /hydrxn/ ihydrxn, ihydrxn2
c
c-----------------------------------------------------------------------
c     Pointer to hydrolysis of organic nitrate
c                    NTR + H2O -> HNO3
c
      integer ihonrxn
      common /honrxn/ ihonrxn
c
c-----------------------------------------------------------------------
c     Pointer used to lookup pig chemistry rate constant
c
c     ipigrxn  -- pointer to NO self-reaction
c                    NO + NO -> 2 NO2
c
      integer ipigrxn
c
      common /pigrxn/ ipigrxn

      integer, parameter :: l_O    = 1,
     &                      l_O1D  = 2,
     &                      l_OH   = 3,
     &                      l_HO2  = 4,
     &                      l_NO3  = 5,
     &                      l_N2O5 = 6,
     &                      l_NO   = 7,
     &                      l_NO2  = 8,
     &                      l_O3   = 9,
     &                      l_HONO = 10,
     &                      l_HNO3 = 11,
     &                      l_CO   = 12,
     &                      l_FORM = 13,
     &                      l_SO2  = 14,
     &                      l_SULF = 15
      integer, parameter :: NRPIGCHEM = 23
      integer, parameter :: NSPIGCHEM = 15
      integer, dimension(NSPIGCHEM) :: lsmap
      integer, dimension(NRPIGCHEM) :: lrmap
      common /pigchemmap/ lsmap, lrmap
c
c----------------------------------------------------------------------
c    Variables for controlling calls to aerosol routines
c
c     dtaero     -- user input time interval (min) between calls to aerosol 
c                   routines
c     dt_aero    -- adjusted (for I/O frequency) time interval (min) between
c                   calls to aerosol routines
c
      real dtaero
      real dt_aero
c
      common /aero_t/ dtaero, dt_aero
