      subroutine cpamech2( r, rk, dtfact, nr, pa, npa, npa_init, ldark )
      use filunit
      use tracer
      use procan
c
c----CAMx v6.30 160408
c
c     Copyright 1996 - 2016
c     Ramboll ENVIRON
c
C***********************************************************************
C  Called by CHEMDRIV, uses integrated reaction rates (R) to calculate
C  important chemical process rates (PA)
C
C   *** NOTE:  This code is hardwired for the CAMx CB6r2 mechanism 2 ***
C
C  Arguments:  R should be the average rate during the most recent
C       chemistry time step, multipled by the time step, eg:
C       the chem solver calculates 0.5*dt*(R+Rold) and passes it
C       to this routine. It's OK to use simply R*dt, but this
C       is a slightly less accurate form of the integration.
C       Important reaction rates are summed below to calculate PA
C       which is passed back to the Chem routine and accumulated for
C       one hour and then output.
C       RK is the rate constants in ppm-n hr-1.
C       DTFACT is the ratio of time step to averaging interval.
C       NR is the number of reactions.
C       NPA is the number of chemical process rates calculated below.
C       NPA_INIT sets num of outputs on first dummy call from pasetup.
C       LDARK is flag set true at night.
C       R is assumed to be ppm.
C       PA is converted to ppb.
C
C** REVISION HISTORY:
C**   NO.    DATE   WHO  WHAT
C**   ---    -----  ---  --------------------------------------------
C**   01     14/07  GY  Created
C**
C***********************************************************************
C
      IMPLICIT NONE
C
      include 'camx.prm'
C
C... Local parameter sets the cut-point between NOx and VOC sensitive
C    O3 production.  Default = 0.35.  Recommended range is 0.15 to 0.35
C
      REAL  ratio_cut
      PARAMETER (ratio_cut = 0.35)
C
C... Factor to convert PPM to PPB
C
      REAL  ppbfact
      PARAMETER (ppbfact = 1000.0)
C
C... Argument declarations
      INTEGER  NR, NPA, NPA_INIT
      REAL     R(NR), PA(NPA), RK(NR)
      REAL     DTFACT
      LOGICAL  LDARK
C
C... Local variable declarations
      REAL   ratio_ind, prod_h2o2, prod_hno3
      REAL   o3_prod, o3_loss , POx_net
      REAL   sum, tmp, ho2tmp, OHwHC
      INTEGER   n, nn
C
C***********************************************************************
C    Calculation of these PA outputs is currently hardwired below
C
C    Oxidant and Ozone Production and Loss
C
C     OxProd
C     OxLoss
C     PO3_net
C     PO3_VOCsns
C     PO3_NOxsns
C     PH2O2_PHN3
C     O3_dest
C
C   OH Reactions
C
C     OHw_CO
C     OHw_CH4
C     OHw_ETHA
C     OHw_PRPA
C     OHw_PAR
C     OHw_BENZ
C     OHw_TOL
C     OHw_XYL
C     OHw_ETH
C     OHw_ETHA
C     OHw_OLE
C     OHw_IOLE
C     OHw_ISOP
C     OHw_TERP
C     OHw_ETHY
C     OHw_all_HC
C
C    NOy Chemistry
C
C     HNO3_OHNO2
C     HNO3_NO3HC
C     HNO3_N2O5
C     NTR1_prod
C     NTR2_prod
C     INTR_prod
C     NTR1toNTR2
C     INTRtoNTR2
C     NOxrecycl
C
C    Photolysis Rates
C
C     J_NO2
C     J_O3O1D
C
C***********************************************************************
C
C     Oxidant and Ozone Production and Loss
C
C     Ox = O3, NO2, NO3*2, O, O1D, HNO3, PAN, PANX, OPAN, PNA, N2O5*3, 
C          NTR1, NTR2, INTR, CRON
C
      nn =  1
      ptname(nn)  = 'OxProd'
      PA(nn) =  
     &      +(1.000)*r(16)  ! OH + OH = O
     &      +(2.000)*r(24)  ! NO + NO + O2 = 2 NO2
     &      +(1.000)*r(25)  ! HO2 + NO = OH + NO2
     &      +(1.000)*r(42)  ! HONO + HONO = NO + NO2
     &      +(1.000)*r(44)  ! HONO + OH = NO2
     &      +(1.000)*r(46)  ! HNO3 + OH = NO3
     &      +(0.410)*r(50)  ! PNA = 0.59 HO2 + 0.59 NO2 + 0.
     &      +(1.000)*r(53)  ! C2O3 + NO = NO2 + MEO2 + RO2
     &      +(0.400)*r(56)  ! PAN = 0.6 NO2 + 0.6 C2O3 + 0.4
     &      +(0.150)*r(57)  ! C2O3 + HO2 = 0.41 PACD + 0.15 
     &      +(1.000)*r(61)  ! CXO3 + NO = NO2 + ALD2 + XO2H 
     &      +(0.400)*r(64)  ! PANX = 0.6 NO2 + 0.6 CXO3 + 0.
     &      +(0.150)*r(65)  ! CXO3 + HO2 = 0.41 PACD + 0.15 
     &      +(1.000)*r(71)  ! MEO2 + NO = FORM + HO2 + NO2
     &      +(1.000)*r(75)  ! XO2H + NO = NO2 + HO2
     &      +(1.000)*r(79)  ! XO2 + NO = NO2
     &      +(1.000)*r(83)  ! XO2N + NO = 0.5 NTR1 + 0.5 NTR
     &      +(1.000)*r(103)  ! HCO3 + NO = FACD + NO2 + HO2
     &      +(1.000)*r(151)  ! ISO2 + NO = 0.1 INTR + 0.9 NO2
     &      +(1.000)*r(167)  ! EPX2 + NO = 0.275 GLYD + 0.275
     &      +(0.185)*r(170)  ! INTR + OH = 0.63 XO2 + 0.37 XO
     &      +(1.000)*r(176)  ! BZO2 + NO = 0.918 NO2 + 0.082 
     &      +(1.000)*r(181)  ! TO2 + NO = 0.86 NO2 + 0.14 NTR
     &      +(1.000)*r(186)  ! XLO2 + NO = 0.86 NO2 + 0.14 NT
     &      +(1.000)*r(207)  ! OPO3 + NO = NO2 + 0.5 GLY + 0.
C
      nn = nn + 1
      ptname(nn)  = 'OxLoss'
      PA(nn) =  
     &      +(2.000)*r(5)  ! O + NO2 = NO
     &      +(2.000)*r(7)  ! O + O3 =
     &      +(1.000)*r(11)  ! O1D + H2O = 2 OH
     &      +(1.000)*r(12)  ! O3 + OH = HO2
     &      +(1.000)*r(13)  ! O3 + HO2 = OH
     &      +(1.000)*r(14)  ! OH + O = HO2
     &      +(1.000)*r(15)  ! HO2 + O = OH
     &      +(1.000)*r(23)  ! H2O2 + O = OH + HO2
     &      +(2.000)*r(28)  ! NO3 = NO
     &      +(2.000)*r(30)  ! NO3 + NO2 = NO + NO2
     &      +(2.000)*r(31)  ! NO3 + O = NO2
     &      +(1.000)*r(32)  ! NO3 + OH = HO2 + NO2
     &      +(1.000)*r(33)  ! NO3 + HO2 = OH + NO2
     &      +(2.000)*r(34)  ! NO3 + O3 = NO2
     &      +(2.000)*r(35)  ! NO3 + NO3 = 2 NO2
     &      +(1.000)*r(39)  ! N2O5 + H2O = 2 HNO3
     &      +(1.000)*r(41)  ! NO + NO2 + H2O = 2 HONO
     &      +(1.000)*r(99)  ! FORM + O = OH + HO2 + CO
     &      +(1.000)*r(100)  ! FORM + NO3 = HNO3 + HO2 + CO
     &      +(1.000)*r(105)  ! ALD2 + O = C2O3 + OH
     &      +(1.000)*r(107)  ! ALD2 + NO3 = C2O3 + HNO3
     &      +(1.000)*r(109)  ! ALDX + O = CXO3 + OH
     &      +(1.000)*r(111)  ! ALDX + NO3 = CXO3 + HNO3
     &      +(1.000)*r(115)  ! GLYD + NO3 = HNO3 + C2O3
     &      +(1.000)*r(118)  ! GLY + NO3 = HNO3 + 1.5 CO + 0.
     &      +(1.000)*r(120)  ! MGLY + NO3 = HNO3 + C2O3 + XO2
     &      +(1.000)*r(137)  ! ETH + O = FORM + HO2 + CO + 0.
     &      +(1.000)*r(139)  ! ETH + O3 = FORM + 0.51 CO + 0.
     &      +(1.000)*r(140)  ! ETH + NO3 = 0.5 NO2 + 0.5 NTR1
     &      +(1.000)*r(141)  ! OLE + O = 0.2 ALD2 + 0.3 ALDX 
     &      +(1.000)*r(143)  ! OLE + O3 = 0.295 ALD2 + 0.555 
     &      +(1.000)*r(144)  ! OLE + NO3 = 0.5 NO2 + 0.5 NTR1
     &      +(1.000)*r(145)  ! IOLE + O = 1.24 ALD2 + 0.66 AL
     &      +(1.000)*r(147)  ! IOLE + O3 = 0.732 ALD2 + 0.442
     &      +(1.000)*r(148)  ! IOLE + NO3 = 0.5 NO2 + 0.5 NTR
     &      +(1.000)*r(150)  ! ISOP + O = 0.75 ISPD + 0.5 FOR
     &      +(1.000)*r(156)  ! ISOP + O3 = 0.6 FORM + 0.65 IS
     &      +(1.000)*r(157)  ! ISOP + NO3 = 0.35 NO2 + 0.65 N
     &      +(1.000)*r(159)  ! ISPD + O3 = 0.04 ALD2 + 0.231 
     &      +(1.000)*r(160)  ! ISPD + NO3 = 0.717 HNO3 + 0.14
     &      +(1.000)*r(164)  ! HPLD + NO3 = HNO3 + ISPD
     &      +(1.000)*r(168)  ! EPX2 + C2O3 = 0.22 GLYD + 0.22
     &      +(1.000)*r(171)  ! TERP + O = 0.15 ALDX + 5.12 PA
     &      +(1.000)*r(173)  ! TERP + O3 = 0.57 OH + 0.07 XO2
     &      +(1.000)*r(174)  ! TERP + NO3 = 0.47 NO2 + 0.28 X
     &      +(1.000)*r(191)  ! CRES + NO3 = 0.3 CRO + HNO3 + 
     &      +(1.000)*r(195)  ! CRON + NO3 = NTR2 + 0.5 CRO + 
     &      +(1.000)*r(196)  ! CRON = HONO + HO2 + FORM + OPE
     &      +(1.000)*r(199)  ! XOPN + O3 = 1.2 MGLY + 0.5 OH 
     &      +(1.000)*r(200)  ! XOPN + NO3 = 0.5 NO2 + 0.5 NTR
     &      +(1.000)*r(203)  ! OPEN + O3 = 1.4 GLY + 0.24 MGL
     &      +(1.000)*r(204)  ! OPEN + NO3 = OPO3 + HNO3
     &      +(1.000)*r(206)  ! CAT1 + NO3 = CRO + HNO3
C
C...  calculate ratio of P(H2O2)/P(HNO3) to use as indicator
C     of NOX or VOC sensitivity
      prod_h2o2 =  R(19) + R(20)
      prod_hno3 =  R(45)
      if (prod_hno3 .GT. 0.0) then
        ratio_ind =  prod_h2o2/prod_hno3
      else
        ratio_ind = 999.
      end if
C
C...  Net Ox Prod sensitive to VOC or NOx
c      nn =  nn + 2
c      ptname(nn-1)   = 'POx_VOCsns'
c      ptname(nn) = 'POx_NOxsns'
c      POx_net = PA(1) - PA(2)
c      if (POx_net .LT. 0.0) POx_net = 0.0
C
C...  Increment POx
c      if (ratio_ind .LT. ratio_cut ) then
c        PA(nn-1)   = POx_net
c        PA(nn) = 0.0
c      else
c        PA(nn-1)   = 0.0
c        PA(nn) = POx_net
c      end if
C
C
C...  Net O3 Production 
      nn =  nn + 1
      ptname(nn)   = 'PO3_net'
      O3_prod =
     &      +         r(  2)  ! O + O2 + M = O3 + M
     &      +( 0.150)*r( 57)  ! C2O3 + HO2 = 0.41 PACD + 0.15 
     &      +( 0.150)*r( 65)  ! CXO3 + HO2 = 0.41 PACD + 0.15 
     &      +( 0.150)*r(210)  ! OPO3 + HO2 = 0.41 PACD + 0.15 
C
      O3_loss =
     &      +         r(  3)  ! O3 + NO = NO2
     &      +         r(  7)  ! O + O3 =
     &      +         r(  8)  ! O3 = O
     &      +         r(  9)  ! O3 = O1D
     &      +         r( 12)  ! O3 + OH = HO2
     &      +         r( 13)  ! O3 + HO2 = OH
     &      +         r( 26)  ! NO2 + O3 = NO3
     &      +         r( 34)  ! NO3 + O3 = NO2
     &      +         r(139)  ! ETH + O3 = FORM + 0.51 CO + 0.
     &      +         r(143)  ! OLE + O3 = 0.295 ALD2 + 0.555 
     &      +         r(147)  ! IOLE + O3 = 0.732 ALD2 + 0.442
     &      +         r(156)  ! ISOP + O3 = 0.6 FORM + 0.65 IS
     &      +         r(159)  ! ISPD + O3 = 0.04 ALD2 + 0.231 
     &      +         r(173)  ! TERP + O3 = 0.57 OH + 0.07 XO2
     &      +         r(199)  ! XOPN + O3 = 1.2 MGLY + 0.5 OH 
     &      +         r(203)  ! OPEN + O3 = 1.4 GLY + 0.24 MGL
C
      PA(nn) = O3_prod - O3_loss
C
C...   Net O3 Prod sensitive to VOC or NOx
      nn =  nn + 2
      ptname(nn-1) = 'PO3_VOCsns'
      ptname(nn)   = 'PO3_NOxsns'
      if (O3_prod - O3_loss .GT. 0.0) then
        if (ratio_ind .LT. ratio_cut ) then
          PA(nn-1) = O3_prod - O3_loss
          PA(nn)   = 0.0
        else
          PA(nn-1) = 0.0
          PA(nn)   = O3_prod - O3_loss
        endif
      else
        PA(nn-1) = 0.0
        PA(nn)   = 0.0
      endif
C
C...   Value of PHNO3/PH2O2 used as VOC vs NOx indicator
      if(.NOT. lcpacum) then
        nn =  nn + 1
        ptname(nn)   = 'PH2O2_PHN3'
        if (ldark) then
          PA(nn) = -999. * (dtfact/ppbfact)
        else
          PA(nn) = ratio_ind * (dtfact/ppbfact)
        endif
      endif
C
C...  O3 destruction by several pathways 
C
      nn =  nn + 1
      ptname(nn)   = 'O3_dest'
C
C...  O1D + water
      PA(nn) =
     &      -         r( 11) !  11  O1D + H2O = 2 OH
C
C...  HO2 + O3 (assuming no OH is recycled via OH+H2O2)
      PA(nn) =  PA(nn)
     &      -         r( 13) !  13  O3 + HO2 = OH +
C
C...  OH + O3 (accounting for any NO2 formed)
C
C     ho2tmp is HO2 destruction without NO2 production
      ho2tmp =  0.0
     &      +         r(13)  ! O3 + HO2 = OH
     &      +         r(15)  ! HO2 + O = OH
     &      +         r(18)  ! OH + HO2 =
     &      +( 2.000)*r(19)  ! HO2 + HO2 = H2O2
     &      +( 2.000)*r(20)  ! HO2 + HO2 + H2O = H2O2
     &      +         r(57)  ! C2O3 + HO2 = 0.41 PACD + 0.15 
     &      +         r(65)  ! CXO3 + HO2 = 0.41 PACD + 0.15 
     &      +         r(72)  ! MEO2 + HO2 = 0.9 MEPX + 0.1 FO
     &      +         r(76)  ! XO2H + HO2 = ROOH
     &      +         r(80)  ! XO2 + HO2 = ROOH
     &      +         r(84)  ! XO2N + HO2 = ROOH
     &      +         r(101)  ! FORM + HO2 = HCO3
     &      +( 0.800)*r(104)  ! HCO3 + HO2 = 0.5 MEPX + 0.5 FA
     &      +( 0.880)*r(152)  ! ISO2 + HO2 = 0.88 ISPX + 0.12 
     &      +( 0.175)*r(166)  ! EPX2 + HO2 = 0.275 GLYD + 0.27
     &      +         r(178)  ! BZO2 + HO2 =
     &      +         r(183)  ! TO2 + HO2 =
     &      +         r(187)  ! XLO2 + HO2 =
     &      +         r(193)  ! CRO + HO2 = CRES
     &      +         r(210)  ! OPO3 + HO2 = 0.41 PACD + 0.15 
C
      PA(nn) =  PA(nn)
     &       - R(12) * ho2tmp
     &         / ( ho2tmp+R(25)+R(33) )
C r(25)  ! HO2 + NO = OH + NO2
C r(33)  ! NO3 + HO2 = OH + NO2
C
C...  O(3P) + VOC
      PA(nn) =  PA(nn)
     &      -         r(99)  ! FORM - O = OH - HO2 - CO
     &      -         r(105)  ! ALD2 - O = C2O3 - OH
     &      -         r(109)  ! ALDX - O = CXO3 - OH
     &      -         r(137)  ! ETH - O = FORM - HO2 - CO - 0.
     &      -         r(141)  ! OLE - O = 0.2 ALD2 - 0.3 ALDX 
     &      -         r(145)  ! IOLE - O = 1.24 ALD2 - 0.66 AL
     &      -         r(150)  ! ISOP - O = 0.75 ISPD - 0.5 FOR
     &      -         r(171)  ! TERP - O = 0.15 ALDX - 5.12 PA
C...  O3 + VOC
      PA(nn) =  PA(nn)
     &      -         r(139)  ! ETH - O3 = FORM - 0.51 CO - 0.
     &      -         r(143)  ! OLE - O3 = 0.295 ALD2 - 0.555 
     &      -         r(147)  ! IOLE - O3 = 0.732 ALD2 - 0.442
     &      -         r(156)  ! ISOP - O3 = 0.6 FORM - 0.65 IS
     &      -         r(159)  ! ISPD - O3 = 0.04 ALD2 - 0.231 
     &      -         r(173)  ! TERP - O3 = 0.57 OH - 0.07 XO2
     &      -         r(199)  ! XOPN - O3 = 1.2 MGLY - 0.5 OH 
     &      -         r(203)  ! OPEN - O3 = 1.4 GLY - 0.24 MGL
C
      PA(nn) = amin1( PA(nn), (O3_prod - O3_loss) )
C
C
C--------------------End of Ox & O3-----------------------
C
C     OH Reactions
C
C
C...  OH+CO
      nn = nn + 1
      ptname(nn)  = 'OHw_CO'
      PA(nn) = R(123)
C
C...  OH+CH4
      nn = nn + 1
      ptname(nn)  = 'OHw_CH4'
      PA(nn) = R(124)
C
C...  OH+ECH4
      nn = nn + 1
      ptname(nn)  = 'OHw_ECH4'
      PA(nn) = R(216)
C
C...  OH+ETHA
      nn = nn + 1
      ptname(nn)  = 'OHw_ETHA'
      PA(nn) = R(125)
C
C...  OH+PRPA
      nn = nn + 1
      ptname(nn)  = 'OHw_PRPA'
      PA(nn) = R(131)
C
C...  OH+PAR
      nn = nn + 1
      ptname(nn)  = 'OHw_PAR'
      PA(nn) = R(132)
C
C...  OH+BENZ
      nn = nn + 1
      ptname(nn)  = 'OHw_BENZ'
      PA(nn) = R(175)
C
C...  OH+TOL
      nn = nn + 1
      ptname(nn)  = 'OHw_TOL'
      PA(nn) = R(180)
C
C...  OH+XYL
      nn = nn + 1
      ptname(nn)  = 'OHw_XYL'
      PA(nn) = R(185)
C
C...  OH+ETH
      nn = nn + 1
      ptname(nn)  = 'OHw_ETH'
      PA(nn) = R(138)
C
C...  OH+OLE
      nn = nn + 1
      ptname(nn)  = 'OHw_OLE'
      PA(nn) = R(142)
C
C...  OH+IOLE
      nn = nn + 1
      ptname(nn)  = 'OHw_IOLE'
      PA(nn) = R(146)
C
C...  OH+ISOP
      nn = nn + 1
      ptname(nn)  = 'OHw_ISOP'
      PA(nn) = R(149)
C
C...  OH+TERP
      nn = nn + 1
      ptname(nn)  = 'OHw_TERP'
      PA(nn) = R(172)
C
C...  OH+ETHY
      nn = nn + 1
      ptname(nn)  = 'OHw_ETHY'
      PA(nn) = R(136)
C
C...  OH +  all organics
      nn = nn + 1
      ptname(nn)  = 'OHw_all_HC'
      OHwHC = 0.0
     &      +         r( 87)  ! MEPX + OH = 0.6 MEO2 + 0.6 RO2
     &      +         r( 89)  ! ROOH + OH = 0.54 XO2H + 0.06 X
     &      +         r( 93)  ! FACD + OH = HO2
     &      +         r( 94)  ! AACD + OH = MEO2 + RO2
     &      +         r( 95)  ! PACD + OH = C2O3
     &      +         r( 96)  ! FORM + OH = HO2 + CO
     &      +         r(106)  ! ALD2 + OH = C2O3
     &      +         r(121)  ! MGLY + OH = C2O3 + CO
     &      +         r(123)  ! CO + OH = HO2
     &      +         r(124)  ! CH4 + OH = MEO2 + RO2
     &      +         r(125)  ! ETHA + OH = 0.991 ALD2 + 0.991
     &      +         r(126)  ! MEOH + OH = FORM + HO2
     &      +         r(127)  ! ETOH + OH = 0.95 ALD2 + 0.9 HO
     &      +         r(130)  ! ACET + OH = FORM + C2O3 + XO2 
     &      +         r(131)  ! PRPA + OH = 0.71 ACET + 0.26 A
     &      +         r(132)  ! PAR + OH = 0.11 ALDX + 0.76 RO
     &      +         r(136)  ! ETHY + OH = 0.7 GLY + 0.7 OH +
     &      +         r(138)  ! ETH + OH = XO2H + RO2 + 1.56 F
     &      +         r(142)  ! OLE + OH = 0.781 FORM + 0.488 
     &      +         r(146)  ! IOLE + OH = 1.3 ALD2 + 0.7 ALD
     &      +         r(149)  ! ISOP + OH = ISO2 + RO2
     &      +         r(158)  ! ISPD + OH = 0.022 XO2N + 0.521
     &      +         r(162)  ! ISPX + OH = 0.904 EPOX + 0.933
     &      +         r(165)  ! EPOX + OH = EPX2 + RO2
     &      +         r(170)  ! INTR + OH = 0.63 XO2 + 0.37 XO
     &      +         r(172)  ! TERP + OH = 0.75 XO2H + 0.5 XO
     &      +         r(175)  ! BENZ + OH = 0.53 CRES + 0.352 
     &      +         r(180)  ! TOL + OH = 0.18 CRES + 0.65 TO
     &      +         r(185)  ! XYL + OH = 0.155 CRES + 0.544 
     &      +         r(205)  ! CAT1 + OH = 0.14 FORM + 0.2 HO
     &      +         r(213)  ! OPAN + OH = 0.5 NO2 + 0.5 GLY 
     &      +         r(214)  ! PANX + OH = ALD2 + NO2
     &      +         r(216)  ! ECH4 + OH = MEO2 + RO2
C
C...  OH reacted
      nn = nn + 1
      ptname(nn)  = 'OH_rctd'
      PA(nn) = OHwHC
     &      +         r( 12)  ! O3 + OH = HO2
     &      +         r( 14)  ! OH + O = HO2
     &      +( 2.000)*r( 16)  ! OH + OH = O
     &      +( 2.000)*r( 17)  ! OH + OH = H2O2
     &      +         r( 18)  ! OH + HO2 =
     &      +         r( 22)  ! H2O2 + OH = HO2
     &      +         r( 32)  ! NO3 + OH = HO2 + NO2
     &      +         r( 40)  ! NO + OH = HONO
     &      +         r( 44)  ! HONO + OH = NO2
     &      +         r( 45)  ! NO2 + OH = HNO3
     &      +         r( 46)  ! HNO3 + OH = NO3
     &      +         r( 51)  ! PNA + OH = NO2
     &      +         r( 52)  ! SO2 + OH = SULF + HO2
     &      +         r( 87)  ! MEPX + OH = 0.6 MEO2 + 0.6 RO2
     &      +         r( 89)  ! ROOH + OH = 0.54 XO2H + 0.06 X
     &      +         r( 91)  ! NTR1 + OH = NTR2
     &      +         r(122)  ! H2 + OH = HO2
C
C-----------------End of OH Reactions-------------------------
C
C
C     NOy Chemistry
C
C
C...  HNO3 production from OH+NO2 
      nn = nn + 1
      ptname(nn)  = 'HNO3_OHNO2'
      PA(nn) = 
     &      +         r(45)  ! NO2 + OH = HNO3
C
C...   HNO3 production from NO3 
      nn = nn + 1
      ptname(nn)  = 'HNO3_NO3HC'
      PA(nn) = 
     &      +         r(100)  ! FORM + NO3 = HNO3 + HO2 + CO
     &      +         r(107)  ! ALD2 + NO3 = C2O3 + HNO3
     &      +         r(111)  ! ALDX + NO3 = CXO3 + HNO3
     &      +         r(115)  ! GLYD + NO3 = HNO3 + C2O3
     &      +         r(118)  ! GLY + NO3 = HNO3 + 1.5 CO + 0.
     &      +         r(120)  ! MGLY + NO3 = HNO3 + C2O3 + XO2
     &      +( 0.717)*r(160)  ! ISPD + NO3 = 0.717 HNO3 + 0.14
     &      +         r(164)  ! HPLD + NO3 = HNO3 + ISPD
     &      +         r(191)  ! CRES + NO3 = 0.3 CRO + HNO3 + 
     &      +         r(195)  ! CRON + NO3 = NTR2 + 0.5 CRO + 
     &      +         r(204)  ! OPEN + NO3 = OPO3 + HNO3
     &      +         r(206)  ! CAT1 + NO3 = CRO + HNO3
C
C...   HNO3 production from N2O5 
      nn = nn + 1
      ptname(nn)  = 'HNO3_N2O5'
      PA(nn) = 
     &      +( 2.000)*r(39)  ! N2O5 + H2O = 2 HNO3
C
C...   Organic Nitrate Production 
C
      nn = nn + 1
      ptname(nn)  = 'NTR1_prod'
      PA(nn) =  
     &      +( 0.500)*r(83)  ! XO2N + NO = 0.5 NTR1 + 0.5 NTR
     &      +         r(135)  ! ROR + NO2 = NTR1
     &      +( 0.500)*r(140)  ! ETH + NO3 = 0.5 NO2 + 0.5 NTR1
     &      +( 0.500)*r(144)  ! OLE + NO3 = 0.5 NO2 + 0.5 NTR1
     &      +( 0.500)*r(148)  ! IOLE + NO3 = 0.5 NO2 + 0.5 NTR
C
      nn = nn + 1
      ptname(nn)  = 'NTR2_prod'
      PA(nn) =  
     &      +( 0.500)*r(83)  ! XO2N + NO = 0.5 NTR1 + 0.5 NTR
     &      +         r(91)  ! NTR1 + OH = NTR2
     &      +( 0.650)*r(157)  ! ISOP + NO3 = 0.35 NO2 + 0.65 N
     &      +( 0.142)*r(160)  ! ISPD + NO3 = 0.717 HNO3 + 0.14
     &      +( 0.266)*r(170)  ! INTR + OH = 0.63 XO2 + 0.37 XO
     &      +( 0.530)*r(174)  ! TERP + NO3 = 0.47 NO2 + 0.28 X
     &      +( 0.082)*r(176)  ! BZO2 + NO = 0.918 NO2 + 0.082 
     &      +( 0.140)*r(181)  ! TO2 + NO = 0.86 NO2 + 0.14 NTR
     &      +( 0.140)*r(186)  ! XLO2 + NO = 0.86 NO2 + 0.14 NT
     &      +         r(194)  ! CRON + OH = NTR2 + 0.5 CRO
     &      +         r(195)  ! CRON + NO3 = NTR2 + 0.5 CRO + 
     &      +( 0.500)*r(200)  ! XOPN + NO3 = 0.5 NO2 + 0.5 NTR
     &      +( 0.500)*r(213)  ! OPAN + OH = 0.5 NO2 + 0.5 GLY 
     &      +         r(215)  ! NTR2 = HNO3
C
      nn = nn + 1
      ptname(nn)  = 'INTR_prod'
      PA(nn) =  
     &      +( 0.100)*r(151)  ! ISO2 + NO = 0.1 INTR + 0.9 NO2
     &      +         r(170)  ! INTR + OH = 0.63 XO2 + 0.37 XO
C
      nn = nn + 1
      ptname(nn)  = 'NTR1toNTR2'
      PA(nn) =  
     &      +         r(91)  ! NTR1 + OH = NTR2
C
      nn = nn + 1
      ptname(nn)  = 'INTRtoNTR2'
      PA(nn) =  
     &      +( 0.266)*r(170)  ! INTR + OH = 0.63 XO2 + 0.37 XO
C
C...   NOz recycled to NOx 
C     potentially important NOx recycling are
C     OH reaction with nitric acid
C     Nitric acid photolysis
C     Organic nitrate photolysis
C     OH reaction with organic nitrates
      nn = nn + 1
      ptname(nn)  = 'NOxrecycl'
      PA(nn) =  
     &      +         r(46)  ! HNO3 + OH = NO3
     &      +         r(47)  ! HNO3 = OH + NO2
     &      +         r(92)  ! NTR1 = NO2
     &      +( 0.444)*r(170)  ! INTR + OH = 0.63 XO2 + 0.37 XO
C
C-----------------End of NOy Chemistry----------------------------------
C
C
C...  Convert to ppb/hr
      Do n = 1,nn
        PA(n) = ppbfact*PA(n)
      End do
C
C     Photolysis Rates
C
C...  J(NO2) photolysis rate (per hour)
      nn = nn + 1
      ptname(nn)  = 'J_NO2'
      PA(nn) =      rk(1)*dtfact
C
C
C...  J(O3O1D) photolysis rate (per hour)
      nn = nn + 1
      ptname(nn)  = 'J_O3O1D'
      PA(nn) =      rk(9)*dtfact
C
C...  Ckeck that MXCPA is set large enough
C
      If( nn .GT. MXCPA ) Then
         write(iout,'(//,a)') 'ERROR in CPAMECH6'
         write(iout,'(a)')
     &           'Number of outputs requested (NN) exceeds limit.'
         write(iout,'(a)') 'Increase parameter MXCPA and try again.'
         write(iout,'(a,i5)') '  MXCPA =', MXCPA
         write(iout,'(a,i5)') '     NN =', nn
         call camxerr()
      End if
C
C...  Set num of outputs on first dummy call from pasetup
C
      NPA_INIT = nn
C
      Return
      End
